#!/usr/bin/perl -w

use strict;
use Test::More 'no_plan';

use_ok('esmith::rpm::filename');
ok( esmith::rpm::filename->isa('esmith::rpm') );

my @good_expect = (
              { file    => 'e-foo-bar-3.9.1a-01.noarch.rpm',
                name    => 'e-foo-bar',
                version => '3.9.1a',
                release => '01',
                arch    => 'noarch'
              },
              { file    => 'foo-3.9.1-02.noarch.rpm',
                name    => 'foo',
                version => '3.9.1',
                release => '02',
                arch    => 'noarch'
              },
              { file    => 'foo-3.9.1-10.noarch.rpm',
                name    => 'foo',
                version => '3.9.1',
                release => '10',
                arch    => 'noarch'
              },
              { file    => 'man-1.5i2-0.7x.5.i386.rpm',
                name    => 'man',
                version => '1.5i2',
                release => '0.7x.5',
                arch    => 'i386'
              },
              { file    => 'man-1.5i2-0.8.5.i386.rpm',
                name    => 'man',
                version => '1.5i2',
                release => '0.8.5',
                arch    => 'i386'
              },
              { file    => 'quota-1.99-7es.i386.rpm',
                name    => 'quota',
                version => '1.99',
                release => '7es',
                arch    => 'i386'
              },
              { file    => 'quota-2.00pre2-7es.i386.rpm',
                name    => 'quota',
                version => '2.00pre2',
                release => '7es',
                arch    => 'i386'
              },
              { file    => 'quota-2.00pre3-7es.i386.rpm',
                name    => 'quota',
                version => '2.00pre3',
                release => '7es',
                arch    => 'i386'
              },
              { file    => 'quota-2.00pre4-7es.i386.rpm',
                name    => 'quota',
                version => '2.00pre4',
                release => '7es',
                arch    => 'i386'
              },
              { file    => 'quota-2.00-6.i386.rpm',
                name    => 'quota',
                version => '2.00',
                release => '6',
                arch    => 'i386'
              },
              { file    => 'quota-2.00-7.i386.rpm',
                name    => 'quota',
                version => '2.00',
                release => '7',
                arch    => 'i386'
              },
              { file    => 'quota-2.00-7es.i386.rpm',
                name    => 'quota',
                version => '2.00',
                release => '7es',
                arch    => 'i386'
              },
             );


foreach my $expect (@good_expect) {
    my $file = $expect->{file};
    my $rpm = esmith::rpm::filename->new($file);

    isa_ok( $rpm, 'esmith::rpm::filename', $file );

    foreach my $meth (qw(file name version release arch)) {
        is( $rpm->$meth(), $expect->{$meth},    "  $meth" );
    }
}

my @rpms = map { esmith::rpm::filename->new($_->{file}) } @good_expect;
@rpms = sort { $a->cmp($b) } @rpms;

is_deeply( [map { $_->file } @rpms], [map { $_->{file} } @good_expect] );
