#!/usr/bin/perl -w

use strict;
use Test::More 'no_plan';

use_ok('esmith::rpm::filename');
ok( esmith::rpm::filename->isa('esmith::rpm') );

my @good_expect = (
	      {
		file    => 'ServiceLink-NOC-db-update_1.1_patch_01-0.1.3-01.noarch.rpm',
		name	=> 'ServiceLink-NOC-db-update_1.1_patch_01',
		version	=> '0.1.3',
		release => '01',
		arch	=> 'noarch',
		type	=> 'rpm'
	      },
	      {
	        file    => 'ServiceLink-NOC-db-update_1.1_patch_02-0.1.2-01.noarch.rpm',
		name	=> 'ServiceLink-NOC-db-update_1.1_patch_02',
		version	=> '0.1.2',
		release	=> '01',
		arch	=> 'noarch',
		type	=> 'rpm',
	      },
	      {
	        file	=> 'ServiceLink-NOC-db-update_1.1_to_1.2-0.1.41-01.noarch.rpm',
		name	=> 'ServiceLink-NOC-db-update_1.1_to_1.2',
		version	=> '0.1.41',
		release => '01',
		arch	=> 'noarch',
		type	=> 'rpm'
	      },
	      { file	=> 'aspell-.28.2.1-1.i386.rpm',
		name	=> 'aspell',
		version	=> '.28.2.1',
		release => 1,
		arch	=> 'i386',
		type	=> 'rpm',
	      },
              { file    => 'e-foo-bar-3.9.1a-01.noarch.rpm',
                name    => 'e-foo-bar',
                version => '3.9.1a',
                release => '01',
                arch    => 'noarch',
                type    => 'rpm',
              },
              { file    => 'e-foo-bar-3.9.3-01.noarch.rpm',
                name    => 'e-foo-bar',
                version => '3.9.3',
                release => '01',
                arch    => 'noarch',
                type    => 'rpm',
              },
              { file    => '/foo/bar/something/e-foo-bar-3.9.4-01.noarch.rpm',
                name    => 'e-foo-bar',
                version => '3.9.4',
                release => '01',
                arch    => 'noarch',
                type    => 'rpm',
	      },
              { file	=> 'e-smith-release-1.2NOC-01.noarch.rpm',
		name	=> 'e-smith-release',
		version	=> '1.2NOC',
		release	=> '01',
		arch	=> 'noarch',
		type	=> 'rpm',
	      },
	      { file	=> 'e-smith-release-4.0ReyRey1.0-1.noarch.rpm',
		name	=> 'e-smith-release',
		version	=> '4.0ReyRey1.0',
		release	=> '1',
		arch	=> 'noarch',
		type	=> 'rpm',
	      },
   	      {
		file	=> 'eMusic-DR0.9-3.i386.rpm',
		name	=> 'eMusic',
		version	=> 'DR0.9',
		release => 3,
		arch	=> 'i386',
		type	=> 'rpm',
	      },
              { file    => 'foo-3.9.1-02.noarch.srpm',
                name    => 'foo',
                version => '3.9.1',
                release => '02',
                arch    => 'noarch',
                type    => 'srpm',
              },
              { file    => 'foo-3.9.1-10.noarch.src.rpm',
                name    => 'foo',
                version => '3.9.1',
                release => '10',
                arch    => 'noarch',
                type    => 'srpm',
              },
              { file    => '~/whatever//man-1.5i2-0.7x.5.i386',
                name    => 'man',
                version => '1.5i2',
                release => '0.7x.5',
                arch    => 'i386',
                type    => 'string',
              },
              { file    => 'man-1.5i2-0.8.5.i386.srpm',
                name    => 'man',
                version => '1.5i2',
                release => '0.8.5',
                arch    => 'i386',
                type    => 'srpm',
              },
	      { file 	=> 'netatalk-1.4b2+asun2.1.3-7.i386.rpm',
		name	=> 'netatalk',
		version	=> '1.4b2+asun2.1.3',
		release	=> 7,
		arch	=> 'i386',
		type	=> 'rpm',
	      },
              { file    => 'pidentd-2.8.5-3+masq.i386.rpm',
                name    => 'pidentd',
                version => '2.8.5',
                release => '3+masq',
                arch    => 'i386',
                type    => 'rpm',
              },
              { file    => 'quota-1.99-7es.i386.src.rpm',
                name    => 'quota',
                version => '1.99',
                release => '7es',
                arch    => 'i386',
                type    => 'srpm',
              },
              { file    => 'quota-2.00pre2-7es.i386',
                name    => 'quota',
                version => '2.00pre2',
                release => '7es',
                arch    => 'i386',
                type    => 'string',
              },
              { file    => 'quota-2.00pre3-7es.i386.rpm',
                name    => 'quota',
                version => '2.00pre3',
                release => '7es',
                arch    => 'i386',
                type    => 'rpm',
              },
              { file    => 'quota-2.00pre4-7es.i386.srpm',
                name    => 'quota',
                version => '2.00pre4',
                release => '7es',
                arch    => 'i386',
                type    => 'srpm',
              },
              { file    => 'quota-2.00-6.i386',
                name    => 'quota',
                version => '2.00',
                release => '6',
                arch    => 'i386',
                type    => 'string',
              },
              { file    => 'quota-2.00-7.i386.src.rpm',
                name    => 'quota',
                version => '2.00',
                release => '7',
                arch    => 'i386',
                type    => 'srpm',
              },
              { file    => 'quota-2.00-7es.i386.rpm',
                name    => 'quota',
                version => '2.00',
                release => '7es',
                arch    => 'i386',
                type    => 'rpm',
              },
             );


foreach my $expect (@good_expect) {
    my $file = $expect->{file};
    my $rpm = esmith::rpm::filename->new($file);

    for my $test_type (('', '(reload)')) {
        isa_ok( $rpm, 'esmith::rpm::filename', $file );

        foreach my $meth (qw(file name version release arch type)) {
            is( $rpm->$meth(), $expect->{$meth},    "  $meth $test_type" );
        }

        is_deeply( [$rpm->tags], [$rpm->name, $rpm->version, 
                                  $rpm->release, $rpm->arch] );

        $rpm->reload;
    }
}

my @rpms = map { esmith::rpm::filename->new($_->{file}) } @good_expect;
@rpms = sort { int(rand(3)) - 1 } @rpms;
@rpms = sort { $a->cmp($b) } @rpms;

is_deeply( [map { $_->file } @rpms], 
           [map { $_->{file} } @good_expect] );

@rpms = sort { $b->cmp($a) } @rpms;
is_deeply( [map { $_->file } @rpms], 
           [map { $_->{file} } reverse @good_expect] );


my @bad_expect = (
		  # no release
		  'foo-1.2.noarch.rpm'
		 );

foreach my $bad (@bad_expect) {
    ok( !esmith::rpm::filename->new($bad), "bad $bad" );
}
