#!/usr/bin/perl -w

use Cwd;
use File::Basename;
use Text::Autoformat;

my $Dir = shift;
my $Out = shift;
-d $Dir or die "Usage:  $0 <rpm directory> <output filename>\n";

my $cwd = cwd;
my $parentwd = dirname($cwd);

$Dir =~ s{^\.(?!\.)} {$cwd};
$Dir =~ s{^\.\.(?!\.)} {$parentwd};

#print "Dir: $Dir\n"; exit 0;
my @RpmFiles = split /\n/, `find $Dir -name '*.rpm'`;

my $date = localtime;
my $comment = "# RPMs found in $Dir on $date\n";

open OUT, ">$Out" or die "Can't open $Out: $!";

print OUT <<'EOF';
#!/usr/bin/perl -w
use esmith::rpm::filename qw/regex/;
use Test::More 'no_plan';

my @rpms;
while(my $line = <DATA>)
{
    next if ($line =~ /^(?:#.*)?\s*$/);
    push @rpms, [ split(/\s+/,$line,-1) ];  
}

foreach my $rpm (@rpms)
{
    my ($n,$v,$r,$a) = @$rpm;
    is($n eq ($n =~ /^$RE_N$/)[0], 1,"$n".' =~ /^$RE_N$/');
    is($v eq ($v =~ /^$RE_V$/)[0], 1,"$v".' =~ /^$RE_V$/');
    is($r eq ($r =~ /^$RE_R$/)[0], 1,"$r".' =~ /^$RE_R$/');
    is_deeply(["$n-$v" =~ /^$RE_NV$/], [$n,$v], 
	    "$n-$v".' =~ /^$RE_NV$/');
    is_deeply(["$v-$r" =~ /^$RE_VR$/], [$v,$r], 
	    "$v-$r".' =~ /^$RE_VR$/');
    is_deeply(["$n-$v-$r" =~ /^$RE_NVR$/], [$n,$v,$r],
	    "$n-$v-$r".' =~ /^$RE_NVR$/');
    is_deeply(["$n-$v-$r.$a" =~ /^$RE_NVRARCH$/], [$n,$v,$r,$a],
	    "$n-$v-$r.$a".' =~ /^$RE_NVRARCH$/');
    is_deeply(["$n-$v-$r.$a.rpm" =~ /^$RE_FILENAME$/], [$n,$v,$r,$a,'rpm'],
	    "$n-$v-$r.$a.rpm".' =~ /^$RE_FILENAME$/');
    is_deeply(["$n-$v-$r.$a.rpm" =~ /^$RE_NVRARCH(?:\.$RE_EXT)?$/], 
			[$n,$v,$r,$a,'rpm'],
	    "$n-$v-$r.$a.rpm".' =~ /^$RE_NVRARCH(?:\.$RE_EXT)$/');
    is_deeply(["$n-$v-$r.src.rpm" =~ /^$RE_FILENAME$/],
			[$n,$v,$r,undef,'src.rpm'],
	    "$n-$v-$r.src.rpm".' =~ /^$RE_FILENAME$/');
    is_deeply(["$n-$v-$r.src.rpm" =~ /^$RE_NVR(?:$RE_ARCH)?(?:\.$RE_EXT)?$/], 
			[$n,$v,$r,undef,'src.rpm'],
	    "$n-$v-$r.src.rpm".' =~ /^$RE_NVR(?:\.$RE_ARCH(?:\.$RE_EXT)?)?$/');
    is_deeply(["$n-$v-$r.$a.src.rpm" =~ /^$RE_FILENAME$/],
			[$n,$v,$r,$a,'src.rpm'],
	    "$n-$v-$r.$a.src.rpm".' =~ /^$RE_FILENAME$/');
    is_deeply(["$n-$v-$r.$a.src.rpm" =~ /^$RE_NVR(?:\.$RE_ARCH)?(?:\.$RE_EXT)?$/], 
			[$n,$v,$r,$a,'src.rpm'],
	    "$n-$v-$r.$a.src.rpm".' =~ /^$RE_NVR(?:\.$RE_ARCH(?:\.$RE_EXT)?)?$/');
}

__DATA__
EOF

print OUT autoformat $comment;

my $numfiles = scalar(@RpmFiles);
my $len = length($numfiles);
my $count = 0;
foreach my $file (@RpmFiles)
{
    printf("\rProgress: %${len}d/%d RPMs (%3d%s complete)",
	    ++$count, $numfiles, ($count/$numfiles)*100, '%');
    #seek(STDOUT, 0, 0);
    #system("echo -n Progress: $count/$numfiles"); 

    my $res = `rpm -qp --qf '%{NAME} %{VERSION} %{RELEASE} %{ARCH}\n' $file`;
    print OUT $res;
}
close OUT;
print "\n";
