#!/usr/bin/perl -w
use esmith::rpm::filename qw/regex/;
use Test::More 'no_plan';

my @rpms;
while(my $line = <DATA>)
{
    next if ($line =~ /^(?:#.*)?\s*$/);
    push @rpms, [ split(/\s+/,$line,-1) ];  
}

foreach my $rpm (@rpms)
{
    my ($n,$v,$r,$a) = @$rpm;
    is($n eq ($n =~ /^$RE_N$/)[0], 1,"$n".' =~ /^$RE_N$/');
    is($v eq ($v =~ /^$RE_V$/)[0], 1,"$v".' =~ /^$RE_V$/');
    is($r eq ($r =~ /^$RE_R$/)[0], 1,"$r".' =~ /^$RE_R$/');
    is_deeply(["$n-$v" =~ /^$RE_NV$/], [$n,$v], 
	    "$n-$v".' =~ /^$RE_NV$/');
    is_deeply(["$v-$r" =~ /^$RE_VR$/], [$v,$r], 
	    "$v-$r".' =~ /^$RE_VR$/');
    is_deeply(["$n-$v-$r" =~ /^$RE_NVR$/], [$n,$v,$r],
	    "$n-$v-$r".' =~ /^$RE_NVR$/');
    is_deeply(["$n-$v-$r.$a" =~ /^$RE_NVRARCH$/], [$n,$v,$r,$a],
	    "$n-$v-$r.$a".' =~ /^$RE_NVRARCH$/');
    is_deeply(["$n-$v-$r.$a.rpm" =~ /^$RE_FILENAME$/], [$n,$v,$r,$a,'rpm'],
	    "$n-$v-$r.$a.rpm".' =~ /^$RE_FILENAME$/');
    is_deeply(["$n-$v-$r.$a.rpm" =~ /^$RE_NVRARCH(?:\.$RE_EXT)?$/], 
			[$n,$v,$r,$a,'rpm'],
	    "$n-$v-$r.$a.rpm".' =~ /^$RE_NVRARCH(?:\.$RE_EXT)$/');
    is_deeply(["$n-$v-$r.src.rpm" =~ /^$RE_FILENAME$/],
			[$n,$v,$r,undef,'src.rpm'],
	    "$n-$v-$r.src.rpm".' =~ /^$RE_FILENAME$/');
    is_deeply(["$n-$v-$r.src.rpm" =~ /^$RE_NVR(?:$RE_ARCH)?(?:\.$RE_EXT)?$/], 
			[$n,$v,$r,undef,'src.rpm'],
	    "$n-$v-$r.src.rpm".' =~ /^$RE_NVR(?:\.$RE_ARCH(?:\.$RE_EXT)?)?$/');
    is_deeply(["$n-$v-$r.$a.src.rpm" =~ /^$RE_FILENAME$/],
			[$n,$v,$r,$a,'src.rpm'],
	    "$n-$v-$r.$a.src.rpm".' =~ /^$RE_FILENAME$/');
    is_deeply(["$n-$v-$r.$a.src.rpm" =~ /^$RE_NVR(?:\.$RE_ARCH)?(?:\.$RE_EXT)?$/], 
			[$n,$v,$r,$a,'src.rpm'],
	    "$n-$v-$r.$a.src.rpm".' =~ /^$RE_NVR(?:\.$RE_ARCH(?:\.$RE_EXT)?)?$/');
}

__DATA__
# RPMs found in /home/e-smith/files/ibays/library/files/distros/redhat/-
# 7.3/en/os/i386/RedHat/RPMS/ on Thu Aug 22 16:38:13 2002
librsvg 1.0.2 1 i386
docbook-style-xsl 1.49 1 noarch
man-pages 1.48 2 noarch
pango-devel 1.0.1 1 i386
w3c-libwww-apps 5.3.2 5 i386
ncompress 4.2.4 28 i386
tWnn 1.11 20 i386
kruler 3.0.0 5 i386
e2fsprogs-devel 1.27 3 i386
kdbg 1.2.4 4 i386
kdesdk-kbabel 3.0.0 5 i386
ucd-snmp-utils 4.2.4 3 i386
taper 6.9b 4 i386
kde-i18n-Russian 3.0.0 5 noarch
eruby-devel 0.9.7 1 i386
autofs 3.1.7 28 i386
kde-i18n-Chinese-Big5 3.0.0 5 noarch
cdparanoia-devel alpha9.8 8 i386
tux 2.2.5 1 i386
man-pages-ko 20010321 2 noarch
krb5-devel 1.2.4 1 i386
XFree86-tools 4.2.0 8 i386
XFree86-doc 4.2.0 8 i386
cadaver 0.19.1 3 i386
kviewshell 3.0.0 5 i386
openssh-askpass-gnome 3.1p1 3 i386
kde-i18n-Polish 3.0.0 5 noarch
kregexpeditor-devel 3.0.0 4 i386
libuser 0.50.2 1 i386
groff-perl 1.17.2 12 i386
byacc 1.9 19 i386
kdenetwork-devel 3.0.0 4 i386
lisa 3.0.0 4 i386
perl 5.6.1 34.99.6 i386
rsh 0.17 5 i386
openssh-clients 3.1p1 3 i386
elm 2.5.6 2 i386
kdemultimedia-arts 3.0.0 3 i386
librep-devel 0.15.1 3 i386
perl-CPAN 1.59_54 34.99.6 i386
perl-File-MMagic 1.13 14 i386
make 3.79.1 8 i386
util-linux 2.11n 12 i386
zebra 0.92a 3 i386
ucd-snmp 4.2.4 3 i386
tk 8.3.3 67 i386
serviceconf 0.7.0 3 noarch
knewsticker 3.0.0 4 i386
dosfstools 2.8 1 i386
xtoolwait 1.3 1 i386
esound 0.2.24 1 i386
apache 1.3.23 11 i386
pidentd 3.0.14 5 i386
kde2-compat 2.2.2 2 i386
imlib-cfgeditor 1.9.13 3.7.x i386
emacs-leim 21.2 2 i386
sox-devel 12.17.3 4 i386
mozilla-js-debugger 0.9.9 7 i386
recode-devel 3.6 4 i386
qtcups-devel 2.0 7 i386
libjpeg-devel 6b 19 i386
eruby-libs 0.9.7 1 i386
openssl096 0.9.6 6 i386
XFree86-P9000 3.3.6 44 i386
ktalkd 3.0.0 4 i386
cracklib 2.7 15 i386
ethtool 1.5 1 i386
WindowMaker-libs 0.80.0 9 i386
libtool-libs 1.4.2 7 i386
pygtk 0.6.9 3 i386
netpbm-progs 9.24 3 i386
w3m-el-common 1.2.6 1 i386
setuptool 1.8 2 i386
pilot-link 0.9.5 13 i386
php-imap 4.1.2 7 i386
glut-devel 3.7 4 i386
tcllib 1.0 67 i386
m2crypto 0.05_snap4 2 i386
xcin 2.5.3.pre2 10 i386
XFree86 4.2.0 8 i386
libungif-devel 4.1.0 10 i386
eject 2.0.12 4 i386
mod_put 1.3 4 i386
kdepim-cellphone 3.0.0 3 i386
XFree86-Xnest 4.2.0 8 i386
zisofs-tools 1.0.3 3 i386
alchemist-devel 1.0.23 1 i386
amanda-client 2.4.2p2 7 i386
openssl-perl 0.9.6b 18 i386
wordtrans 1.1pre8 10 i386
aspell-pt_BR 2.4 7 i386
librsvg-devel 1.0.2 1 i386
kfax 3.0.0 5 i386
pam_smb 1.1.6 2 i386
autoconf 2.13 17 noarch
ac-archive 0.5.34 1 noarch
ical 2.2 26 i386
nasm-rdoff 0.98.22 2 i386
pam_krb5 1.55 1 i386
kdevelop 2.1 2 i386
netconfig 0.8.11 7 i386
mailman 2.0.9 1 i386
perl-Date-Calc 5.0 15 i386
XFree86-Mach32 3.3.6 44 i386
nss_db-compat 2.2 14 i386
junkbuster 2.0.2 31 i386
mrproject 0.5.1 8 i386
imlib-devel 1.9.13 3.7.x i386
mod_auth_any 1.0.2 1 i386
open 1.4 14 i386
netscape-navigator 4.79 1 i386
kde-i18n-Greek 3.0.0 5 noarch
kernel-debug 2.4.18 3 i686
ntsysv 1.3.5 3 i386
mutt 1.2.5.1 1 i386
pump-devel 0.8.11 7 i386
readline 4.2a 4 i386
esound-devel 0.2.24 1 i386
gdk-pixbuf-devel 0.14.0 8 i386
tetex 1.0.7 47 i386
traceroute 1.4a12 2 i386
slang 1.4.5 2 i386
gnome-mime-data 1.0.4 1 noarch
mysql-server 3.23.49 3 i386
up2date 2.7.86 7.x.3 i386
VFlib2-conf-ja 2.25.6 4 i386
postgresql-devel 7.2.1 5 i386
tetex-xdvi 1.0.7 47 i386
pygtk-libglade 0.6.9 3 i386
namazu-devel 2.0.10 4 i386
gnome-libs-devel 1.4.1.2.90 14 i386
dictd 1.5.5 1 i386
zlib-devel 1.1.3 25.7 i386
kghostview 3.0.0 5 i386
epic 1.0.1 4 i386
php-mysql 4.1.2 7 i386
licq-qt 1.1.0 0.cvs20020416.1 i386
glibc 2.2.5 34 i686
bootparamd 0.17 7 i386
kdepasswd 3.0.0 4 i386
gpm 1.19.3 21 i386
php-manual 4.1.2 7 i386
pygnome-devel 1.4.2 3 i386
mx 2.0.3 1 i386
qt2-devel 2.3.1 3 i386
apel 10.3 4 noarch
ttfonts-zh_CN 2.11 21 noarch
cWnn-common 1.11 20 i386
tripwire 2.3.1 10 i386
docbook-style-dsssl 1.76 1 noarch
stardict 1.31 7 i386
xinetd 2.3.4 0.8 i386
kde-i18n-Brazil 3.0.0 5 noarch
hwdata 0.14 1 noarch
ImageMagick-devel 5.4.3.11 1 i386
cdrecord-devel 1.10 11 i386
metamail 2.7 28 i386
arts-devel 1.0.0 4 i386
kernel 2.4.18 3 i386
netpbm 9.24 3 i386
ttfonts-zh_TW 2.11 10 noarch
kpppload 1.04 36 i386
perl-XML-Encoding 1.01 9 noarch
kde-i18n-Estonian 3.0.0 5 noarch
mew-common 2.2 2 i386
oaf 0.6.8 3 i386
python-clap 1.0.0 3 noarch
perl-Time-HiRes 1.20 14 i386
gimp-print-cups 4.2.0 9 i386
XFree86-xfs 4.2.0 8 i386
kakasi-devel 2.3.4 3 i386
lvm 1.0.3 4 i386
amanda 2.4.2p2 7 i386
xemacs-info 21.4.6 7 i386
popt 1.6.4 7x.18 i386
kdeutils-laptop 3.0.0 4 i386
vim-common 6.1 2 i386
ark 3.0.0 4 i386
ed 0.2 25 i386
MySQL-python 0.9.1 1 i386
libglade2 1.99.9 2 i386
hesiod-devel 3.0.2 18 i386
mod_auth_pgsql 0.9.12 2 i386
tix 8.2.0b1 67 i386
ttfonts-ko 1.0.11 9 noarch
redhat-switchmail-gnome 0.5.1 1 noarch
e2fsprogs 1.27 3 i386
libao 0.8.2 2 i386
cipe 1.4.5 9 i386
xmms-skins 1.2.7 1 i386
tamago 4.0.6 5 noarch
gtk+ 1.2.10 15 i386
cvs 1.11.1p1 7 i386
koncd 3.0.0 3 i386
kdf 3.0.0 4 i386
pump 0.8.11 7 i386
groff 1.17.2 12 i386
wordtrans-web 1.1pre8 10 i386
kdesdk-gimp 3.0.0 5 i386
rep-gtk-gnome 0.15 7 i386
SDL_net 1.2.3 2 i386
XFree86-font-utils 4.2.0 8 i386
fonts-KOI8-R-75dpi 1.0 1 noarch
vixie-cron 3.0.1 64 i386
audiofile-devel 0.2.3 1 i386
gnuplot 3.7.1 17 i386
kernel-pcmcia-cs 3.1.27 18 i386
jed-xjed 0.99.14 2 i386
xosview 1.7.3 10 i386
qt2-designer 2.3.1 3 i386
kernel-smp 2.4.18 3 i686
kljettool 3.0.0 4 i386
libusb-devel 0.1.5 3 i386
qt-Xt 3.0.3 11 i386
pygnome-libglade 1.4.2 3 i386
aumix-X11 2.7 8 i386
iptables 1.2.5 3 i386
glib-devel 1.2.10 5 i386
dhcpcd 1.3.22pl1 7 i386
mkisofs 1.10 11 i386
XFree86-ISO8859-2-100dpi-fonts 4.2.0 8 i386
newt 0.50.35 1 i386
nasm 0.98.22 2 i386
knm_new 1.1 5 noarch
kon2 0.3.9b 7 i386
GConf-devel 1.0.9 4 i386
g-wrap 1.2.1 4 i386
jikes 1.15 1 i386
doxygen 1.2.14 4 i386
glibc-debug 2.2.5 34 i386
psutils 1.17 13 i386
kde-i18n-Norwegian-Nynorsk 3.0.0 5 noarch
mailcap 2.1.9 2 noarch
Glide3 20010520 13 i386
kde-i18n-Slovak 3.0.0 5 noarch
timeconfig 3.2.7 1 i386
adjtimex 1.12 2 i386
ethereal-gnome 0.9.3 3 i386
xpdf-japanese 1.00 3 i386
vnc-doc 3.3.3r2 28 i386
pygnome-gtkhtml 1.4.2 3 i386
glibc-common 2.2.5 34 i386
tmpwatch 2.8.3 1 i386
comsat 0.17 3 i386
patchutils 0.2.11 2 i386
klprfax 3.0.0 4 i386
korn 3.0.0 4 i386
libmng-static 1.0.3 2 i386
alchemist 1.0.23 1 i386
db3 3.3.11 6 i386
koffice 1.1.1 5 i386
hesiod 3.0.2 18 i386
libvorbis-devel 1.0rc3 1 i386
SDL_net-devel 1.2.3 2 i386
gawk 3.1.0 4 i386
chromium 0.9.12 13 i386
cyrus-sasl-devel 1.5.24 25 i386
perl-URI 1.17 16 i386
tetex-dvilj 1.0.7 47 i386
glibc-utils 2.2.5 34 i386
fonts-ISO8859-7-Type1 1.0 2 noarch
qt1x-devel 1.45 16 i386
libmad 0.14.2b 3 i386
kregexpeditor 3.0.0 4 i386
transfig 3.2.3d 2 i386
kdegames-devel 3.0.0 2 i386
kdebase-devel 3.0.0 12 i386
pvm-gui 3.4.4 2 i386
ruby-tcltk 1.6.7 2 i386
iptraf 2.5.0 3 i386
kscd 3.0.0 3 i386
xmms-gnome 1.2.7 1 i386
krbafs 1.1.1 1 i386
gaim 0.53 1 i386
ncurses-devel 5.2 26 i386
autoconvert-xchat 0.3.7 6 i386
aspell-nl 0.1 12 i386
mingetty 1.00 1 i386
timidity++ 2.11.3 1 i386
lftp 2.4.9 1 i386
xawtv 3.73 3 i386
pygtk-glarea 0.6.9 3 i386
gnuchess 4.0.pl80 8 i386
licq 1.1.0 0.cvs20020416.1 i386
fvwm2-icons 2.4.6 1 i386
eel-devel 1.0.2 11 i386
kde-i18n-Finnish 3.0.0 5 noarch
gqview 0.8.1 5 i386
bzip2 1.0.2 2 i386
mkbootdisk 1.4.3 1 i386
perl-SGMLSpm 1.03ii 4 noarch
isdn4k-utils 3.1 53 i386
libtabe-devel 0.2.4a 10 i386
blas-man 3.0 14 i386
memprof 0.4.1 5 i386
gperf 2.7.2 2 i386
desktop-backgrounds 1.1 4 noarch
tcpdump 3.6.2 12 i386
gnome-spell 0.4.1 0.7x i386
festival-devel 1.4.2 3 i386
ftpcopy 0.3.9 1 i386
libcap 1.10 8 i386
VFlib2-VFjfm 2.25.6 4 i386
mozilla-nss-devel 0.9.9 7 i386
man-pages-ja 0.5 4 noarch
perl-TermReadKey 2.17 14 i386
libelf 0.7.0 2 i386
semi-xemacs 1.14.3 11 noarch
alien 7.24 3 noarch
rpm-build 4.0.4 7x.18 i386
kcc 2.3 10 i386
amanda-server 2.4.2p2 7 i386
gcc-chill 2.96 110 i386
kdeaddons-noatun 3.0.0 4 i386
postgresql-server 7.2.1 5 i386
shadow-utils 20000902 7 i386
emacs 21.2 2 i386
ImageMagick 5.4.3.11 1 i386
xtraceroute 0.9.0 6 i386
XFree86-xdm 4.2.0 8 i386
perl-HTML-Tagset 3.03 14 i386
expect 5.32.2 67 i386
kdetoys 3.0.0 3 i386
xemacs 21.4.6 7 i386
dtach 0.5 3 i386
php-pgsql 4.1.2 7 i386
ruby 1.6.7 2 i386
flim-xemacs 1.14.3 4 noarch
redhat-switch-printer 0.5.1 2 noarch
ghostscript 6.52 8 i386
asp2php-gtk 0.76.2 1 i386
procinfo 18 2 i386
mars-nwe 0.99pl20 6 i386
dbskkd-cdb 1.01 13 i386
libxslt 1.0.15 1 i386
dialog 0.9a 5 i386
XFree86-ISO8859-9-100dpi-fonts 4.2.0 8 i386
gcc-java 2.96 110 i386
libmng-devel 1.0.3 2 i386
kdeartwork-locolor 3.0.0 4 i386
libsigc++ 1.0.3 5 i386
ntp 4.1.1 1 i386
kdebase 3.0.0 12 i386
PyQt-devel 3.1 2 i386
lslk 1.29 3 i386
kde-i18n-German 3.0.0 5 noarch
wine-devel 20020327 1 i386
kappa20 0.3 7 noarch
arts 1.0.0 4 i386
lapack 3.0 14 i386
tcl 8.3.3 67 i386
snavigator 5.0 7 i386
libxml2 2.4.19 4 i386
ddskk 11.6.0 6 noarch
kde-i18n-Chinese 3.0.0 5 noarch
aspell-pt 0.1 6 i386
im-sdk 20011223 3 i386
rdist 6.1.5 16 i386
automake 1.4p5 4 noarch
sysctlconfig 0.15 1 i386
mozilla-mail 0.9.9 7 i386
pnm2ppa 1.04 2 i386
reiserfs-utils 3.x.0j 3 i386
xinitrc 3.22 1 noarch
perl-Crypt-SSLeay 0.35 15 i386
postgresql-contrib 7.2.1 5 i386
kmix 3.0.0 3 i386
netatalk-devel 1.5.2 3 i386
bug-buddy 2.0.6 9 i386
jpilot 0.99 87 i386
tftp-server 0.28 2 i386
perl-libwww-perl 5.63 9 i386
basesystem 7.0 2 noarch
wmix 3.0 2 i386
evolution 1.0.3 4 i386
modutils-devel 2.4.14 3 i386
netatalk 1.5.2 3 i386
pine 4.44 7 i386
docbook-utils-pdf 0.6.9 25 noarch
bind 9.2.0 8 i386
libgtop 1.0.12 8 i386
pax 3.0 1 i386
ncurses4 5.0 5 i386
xpdf-chinese-simplified 1.00 3 i386
SDL 1.2.3 7 i386
glib2 2.0.1 2 i386
perl-Text-Kakasi 1.04 4 i386
python2-docs 2.2 16 i386
pygnome-applet 1.4.2 3 i386
kdeaddons-kate 3.0.0 4 i386
squid 2.4.STABLE6 1.7.2 i386
aspell-sv 1.3.6 2 i386
SDL_mixer-devel 1.2.1 4 i386
ruby-libs 1.6.7 2 i386
perl-NDBM_File 1.75 34.99.6 i386
SDL_image 1.2.1 4 i386
ytalk 3.1.1 7 i386
unzip 5.50 2 i386
noatun 3.0.0 3 i386
krb5-server 1.2.4 1 i386
mgetty-sendfax 1.1.28 3 i386
tetex-dvips 1.0.7 47 i386
usbview 1.0 5 i386
miniChinput 0.0.3 18 i386
kppp 3.0.0 4 i386
gnome-vfs-devel 1.0.5 4 i386
cproto 4.6 9 i386
SDL_image-devel 1.2.1 4 i386
wordtrans-kde 1.1pre8 10 i386
sip 3.1 2 i386
yp-tools 2.6 4 i386
kooka 3.0.0 5 i386
dateconfig 0.7.5 5 i386
krb5-workstation 1.2.4 1 i386
vnc 3.3.3r2 28 i386
kde1-compat-devel 1.1.2 11 i386
anacron 2.3 17 i386
kde-i18n-Hungarian 3.0.0 5 noarch
talk 0.17 12 i386
perl-NKF 1.71 2 i386
perl-XML-Dumper 0.4 12 noarch
FreeWnn-libs 1.11 20 i386
libgcj 2.96 29 i386
xchat 1.8.8 5 i386
gnome-core-devel 1.4.0.4 54 i386
unixODBC-kde 2.2.0 5 i386
kudzu 0.99.52 1 i386
Omni 0.5.1 3 i386
mm-devel 1.1.3 4 i386
redhat-switch-printer-gnome 0.5.1 2 noarch
ruby-mode 1.6.7 2 i386
fortune-mod 1.0 20 i386
efax 0.9 12 i386
glib10 1.0.6 10 i386
postgresql-jdbc 7.2.1 5 i386
printconf 0.3.77 1 i386
lm_sensors-devel 2.6.1 1 i386
rdate 1.2 1 i386
jfsutils 1.0.17 1 i386
rpmfind 1.7 7 i386
kdesdk-kmtrace 3.0.0 5 i386
docbook-utils 0.6.9 25 noarch
php 4.1.2 7 i386
gtkglarea 1.2.2 10 i386
xmms-devel 1.2.7 1 i386
compat-egcs 6.2 1.1.2.16 i386
php-ldap 4.1.2 7 i386
readline41 4.1 10 i386
libogg 1.0rc3 1 i386
gphoto2 2.0 4 i386
pan 0.11.2 2 i386
ipchains 1.3.10 13 i386
at 3.1.8 23 i386
tkinter 1.5.2 38 i386
mod_auth_mysql 1.11 1 i386
gdm 2.2.3.1 22 i386
ksirc 3.0.0 4 i386
compat-glibc 6.2 2.1.3.2 i386
htdig-web 3.2.0 2.011302 i386
Gtk-Perl 0.7008 13 i386
xmlto 0.0.8 3 noarch
libtool 1.4.2 7 i386
gcc-objc 2.96 110 i386
fonts-ISO8859-7-100dpi 1.0 2 noarch
gcc 2.96 110 i386
libdbi-devel 0.6.4 2 i386
Canna 3.5b2 62 i386
sendmail 8.11.6 15 i386
sysklogd 1.4.1 8 i386
pvm 3.4.4 2 i386
busybox-anaconda 0.60.2 4 i386
mgetty 1.1.28 3 i386
kdesdk-kbugbuster 3.0.0 5 i386
perl-Bit-Vector 6.1 12 i386
sip-devel 3.1 2 i386
telnet 0.17 20 i386
XFree86-twm 4.2.0 8 i386
sash 3.4 11 i386
nut 0.45.4 1 i386
sgml-common 0.6.3 9 noarch
kWnn 1.11 20 i386
openssl095a 0.9.5a 11 i386
libdbi 0.6.4 2 i386
ksymoops 2.4.4 1 i386
XFree86-Mono 3.3.6 44 i386
perl-DB_File 1.75 34.99.6 i386
nmap-frontend 2.54BETA31 1 i386
parted-devel 1.4.24 3 i386
gnome-pilot-devel 0.1.64 3 i386
namazu 2.0.10 4 i386
postgresql-docs 7.2.1 5 i386
emacspeak 15.0 4 i386
bdflush 1.5 17 i386
aspell-it 0.1 11 i386
kdemultimedia-devel 3.0.0 3 i386
kdeartwork-screensavers 3.0.0 4 i386
Xdialog 2.0.5 1 i386
amanda-devel 2.4.2p2 7 i386
doxygen-doxywizard 1.2.14 4 i386
wireless-tools 23 2 i386
njamd 0.9.2 3 i386
qt1x-GL 1.45 16 i386
Glide3-devel 20010520 13 i386
vim-X11 6.1 2 i386
bindconf 1.6.3 1 noarch
rpm 4.0.4 7x.18 i386
mozilla-chat 0.9.9 7 i386
python2 2.2 16 i386
XFree86-VGA16 3.3.6 44 i386
mod_throttle 3.1.2 5 i386
tcsh 6.10 6 i386
kdict 3.0.0 4 i386
flex 2.5.4a 23 i386
kdeaddons-knewsticker 3.0.0 4 i386
SDL_mixer 1.2.1 4 i386
openssl 0.9.6b 18 i386
wl-xemacs 2.8.1 5 noarch
man-pages-cs 0.14 4 noarch
mtr 0.49 1 i386
libunicode 0.4 6 i386
qt1x 1.45 16 i386
kdelibs-devel 3.0.0 10 i386
rwho 0.17 11 i386
XFree86-xf86cfg 4.2.0 8 i386
bonobo-conf 0.14 5 i386
lam 6.5.6 4 i386
aspell-devel 0.33.7.1 9 i386
locale_config 0.3.4 2 i386
atk-devel 1.0.1 1 i386
openldap-devel 2.0.23 4 i386
libghttp 1.0.9 2 i386
freeciv 1.12.0 1 i386
libesmtp 0.8.4 2 i386
nss_ldap 185 1 i386
xemacs-el 21.4.6 7 i386
w3m-el-xemacs 1.2.6 1 i386
kde-i18n-Portuguese 3.0.0 5 noarch
cups-drivers 1.1 0.20020313.3 i386
portmap 4.0 41 i386
postgresql-tk 7.2.1 5 i386
python2-devel 2.2 16 i386
libgcj-devel 2.96 29 i386
procps 2.0.7 12 i386
cups-devel 1.1.14 15 i386
python-xmlrpc 1.5.1 7.x.3 i386
rpm-perl 4.0.4 7x.18 i386
rusers-server 0.17 12 i386
fonts-ja 7.x 1 noarch
xpdf-chinese-traditional 1.00 3 i386
aspell-da 1.4.22 2 i386
tora 1.2.3 2 i386
XFree86-ISO8859-9-75dpi-fonts 4.2.0 8 i386
crontabs 1.10 1 noarch
cyrus-sasl-gssapi 1.5.24 25 i386
automake15 1.5 2 noarch
pam 0.75 32 i386
hanterm-xf p19 15 i386
vim-enhanced 6.1 2 i386
curl-devel 7.9.5 2 i386
symlinks 1.2 13 i386
pilot-link-devel 0.9.5 13 i386
netscape-common 4.79 1 i386
lm_sensors 2.6.1 1 i386
oaf-devel 0.6.8 3 i386
cdda2wav 1.10 11 i386
ami 1.0.11 9 i386
GConf 1.0.9 4 i386
redhat-logos 1.1.3 1 noarch
libxml2-devel 2.4.19 4 i386
bonobo-devel 1.0.19 2 i386
perl-DBI 1.21 1 i386
ami-gnome 1.0.11 9 i386
VFlib2 2.25.6 4 i386
XFree86-100dpi-fonts 4.2.0 8 i386
mktemp 1.5 14 i386
gnome-games-devel 1.4.0.1 5 i386
kfract 3.0.0 5 i386
g-wrap-devel 1.2.1 4 i386
xisdnload 1.38 53 i386
rpmlint 0.38 5 noarch
mysql-devel 3.23.49 3 i386
isicom 3.05 3 i386
linuxdoc-tools 0.9.16 4 i386
printconf-gui 0.3.77 1 i386
pychecker 0.8.10 1 noarch
gtkhtml-devel 1.0.2 1 i386
imlib 1.9.13 3.7.x i386
qt2 2.3.1 3 i386
ElectricFence 2.2.2 8 i386
kjots 3.0.0 4 i386
qt 3.0.3 11 i386
setup 2.5.12 1 noarch
gsl 1.1.1 1 i386
bridge-utils-devel 0.9.3 4 i386
libglade2-devel 1.99.9 2 i386
rmt 0.4b27 3 i386
gnupg 1.0.6 5 i386
gcc-c++ 2.96 110 i386
kviewshell-devel 3.0.0 5 i386
pspell-devel 0.12.2 8 i386
XFree86-truetype-fonts 4.2.0 8 i386
libtabe 0.2.4a 10 i386
grub 0.91 4 i386
samba-swat 2.2.3a 6 i386
XFree86-Mach64 3.3.6 44 i386
libpcap 0.6.2 12 i386
anaconda 7.3 7 i386
lokkit 0.50 8 i386
nedit 5.2 2 i386
gnumeric 1.0.5 3 i386
termcap 11.0.1 10 noarch
aumix 2.7 8 i386
ppp 2.4.1 3 i386
XFree86-FBDev 3.3.6 44 i386
XFree86-W32 3.3.6 44 i386
exmh 2.4 2 noarch
ImageMagick-perl 5.4.3.11 1 i386
jed 0.99.14 2 i386
gtk-engines 0.11 10 i386
vlock 1.3 8 i386
cWnn 1.11 20 i386
gal-devel 0.19.1 2 i386
tcp_wrappers 7.6 19 i386
kdemultimedia-libs 3.0.0 3 i386
php-odbc 4.1.2 7 i386
aspell-fr 0.1 1 i386
glade 0.6.4 1 i386
krbafs-devel 1.1.1 1 i386
guile-devel 1.3.4 19 i386
w3m 0.3 1 i386
joe 2.9.7 4 i386
libtiff 3.5.7 2 i386
sane-backends-devel 1.0.7 6 i386
jed-common 0.99.14 2 i386
slrn 0.9.7.4 1 i386
XFree86-8514 3.3.6 44 i386
rep-gtk-libglade 0.15 7 i386
sh-utils 2.0.11 14 i386
gnomeicu 0.96.1 3 i386
sylpheed 0.7.3 1 i386
mod_perl 1.26 5 i386
gv 3.5.8 15 i386
gpm-devel 1.19.3 21 i386
foomatic 1.1 0.20020313.3 i386
sane-frontends 1.0.7 2 i386
qt-PostgreSQL 3.0.3 11 i386
kfloppy 3.0.0 4 i386
khexedit 3.0.0 4 i386
eruby 0.9.7 1 i386
perl-DBD-MySQL 1.2219 6 i386
x3270 3.2.18 2 i386
pygnome-capplet 1.4.2 3 i386
freetype 2.0.9 2 i386
qt-static 3.0.3 11 i386
nvi-m17n-nocanna 1.79 20011024.2 i386
fonts-ISO8859-2-75dpi 1.0 3 noarch
openmotif 2.2.2 5 i386
fbset 2.1 8 i386
authconfig 4.2.8 4 i386
fonts-KOI8-R-100dpi 1.0 1 noarch
losetup 2.11n 12 i386
isdn4k-utils-devel 3.1 53 i386
busybox 0.60.2 4 i386
audiofile 0.2.3 1 i386
libunicode-devel 0.4 6 i386
mrtg 2.9.17 3 i386
rp-pppoe 3.3 7 i386
MAKEDEV 3.3 4 i386
firewall-config 0.97 2 i386
emacs-el 21.2 2 i386
blt 2.4u 7 i386
ipxutils 2.2.0.18 6 i386
man 1.5j 6 i386
rhn_register 2.7.21 7.x.3 i386
libjpeg 6b 19 i386
sudo 1.6.5p2 2 i386
gd-progs 1.8.4 4 i386
unix2dos 2.2 15 i386
aspell 0.33.7.1 9 i386
wordtrans-qt 1.1pre8 10 i386
x3270-x11 3.2.18 2 i386
playmidi 2.4 16 i386
mailx 8.1.1 22 i386
kde-i18n-Catalan 3.0.0 5 noarch
diffutils 2.7.2 5 i386
bonobo 1.0.19 2 i386
redhat-lsb 1.1.0 0.5 i386
db3-devel 3.3.11 6 i386
hwcrypto 1.0 3 i386
glibc-profile 2.2.5 34 i386
cups-drivers-pnm2ppa 1.1 0.20020313.3 i386
xscreensaver 3.33 4 i386
swig 1.1p5 12 i386
words 2 18 noarch
namazu-cgi 2.0.10 4 i386
cervisia 3.0.0 5 i386
elinks 0.3.0 1 i386
ncftp 3.1.3 3 i386
control-center-devel 1.4.0.1 31 i386
ktimer 3.0.0 4 i386
xpdf-korean 1.00 3 i386
mgetty-voice 1.1.28 3 i386
diskcheck 1.2 1 noarch
kdepim-devel 3.0.0 3 i386
postgresql-python 7.2.1 5 i386
taipeifonts 1.2 16 noarch
pwdb 0.61.2 2 i386
kpf 3.0.0 4 i386
FreeWnn 1.11 20 i386
aspell-no 0.3 1 i386
man-pages-ru 0.7 1 noarch
intltool 0.17 1 i386
less 358 24 i386
am-utils 6.0.7 4 i386
kde-i18n-Swedish 3.0.0 5 noarch
qt-ODBC 3.0.3 11 i386
kde-i18n-British 3.0.0 5 noarch
kdepim-pilot 3.0.0 3 i386
gal 0.19.1 2 i386
kernel-doc 2.4.18 3 i386
gd-devel 1.8.4 4 i386
smpeg-gtv 0.4.4 9 i386
apache-devel 1.3.23 11 i386
kakasi 2.3.4 3 i386
rwall-server 0.17 10 i386
pygnome 1.4.2 3 i386
unarj 2.43 10 i386
kdebindings 3.0.0 1 i386
dietlibc 0.15 2 i386
kde1-compat 1.1.2 11 i386
mount 2.11n 12 i386
nautilus-mozilla 1.0.6 15 i386
lha 1.14i 4 i386
rpmdb-redhat 7.3 0.20020419 i386
kdemultimedia-kfile 3.0.0 3 i386
qt-designer 3.0.3 11 i386
diffstat 1.28 1 i386
cyrus-sasl-plain 1.5.24 25 i386
textutils 2.0.21 1 i386
screen 3.9.11 3 i386
dmalloc 4.8.1 6 i386
netdump-server 0.6.4 1 i386
xcdroast 0.98a9 8 i386
syslinux 1.52 2 i386
pstack 1.1 1 i386
openmotif-devel 2.2.2 5 i386
tetex-afm 1.0.7 47 i386
libxml10 1.0.0 8 i386
libmng 1.0.3 2 i386
libungif-progs 4.1.0 10 i386
fonts-ISO8859-7 1.0 2 noarch
units 1.74 1 i386
VFlib2-devel 2.25.6 4 i386
ORBit 0.5.13 3 i386
slrn-pull 0.9.7.4 1 i386
postgresql-perl 7.2.1 5 i386
openldap-clients 2.0.23 4 i386
kernel 2.4.18 3 i686
kdoc 3.0.0 0.cvs20020321.1 noarch
glut 3.7 4 i386
net-tools 1.60 4 i386
cpp 2.96 110 i386
perl-Parse-Yapp 1.05 15 i386
perl-CGI 2.752 34.99.6 i386
uucp 1.06.1 33.7.2 i386
specspo 7.3 4 noarch
ORBit-devel 0.5.13 3 i386
octave 2.1.35 4 i386
tetex-doc 1.0.7 47 i386
libtiff-devel 3.5.7 2 i386
Xaw3d-devel 1.5 12 i386
XFree86-ISO8859-2-75dpi-fonts 4.2.0 8 i386
bash 2.05a 13 i386
db3x 3.2.9 4 i386
perl-libxml-perl 0.07 14 noarch
playmidi-X11 2.4 16 i386
kde-i18n-Slovenian 3.0.0 5 noarch
openssh-server 3.1p1 3 i386
skkdic 20020220 2 noarch
festival 1.4.2 3 i386
gsl-devel 1.1.1 1 i386
kcalc 3.0.0 4 i386
mozilla 0.9.9 7 i386
gnome-print 0.35 4 i386
netdump 0.6.4 1 i386
compat-egcs-g77 6.2 1.1.2.16 i386
tuxracer 0.61 8 i386
licq-gnome 1.1.0 0.cvs20020416.1 i386
kdepim 3.0.0 3 i386
mkinitrd 3.3.10 1 i386
ncurses 5.2 26 i386
kdebindings-kmozilla 3.0.0 1 i386
aspell-ca 0.1 13 i386
kde-i18n-Icelandic 3.0.0 5 noarch
compat-libstdc++ 6.2 2.9.0.16 i386
klpq 3.0.0 4 i386
gq 0.4.0 5 i386
openldap 2.0.23 4 i386
finger-server 0.17 9 i386
ghostscript-fonts 5.50 3 noarch
nc 1.10 11 i386
xfig 3.2.3d 3 i386
libesmtp-devel 0.8.4 2 i386
vnc-server 3.3.3r2 28 i386
dvdrecord 0.1.2 1 i386
libuser-devel 0.50.2 1 i386
rxvt 2.7.8 3 i386
rwall 0.17 10 i386
libogg-devel 1.0rc3 1 i386
ttfonts-ja 1.2 8 noarch
nut-client 0.45.4 1 i386
ctags 5.2.2 2 i386
ksnapshot 3.0.0 5 i386
iscsi 2.1.0.20 4 i386
glibc-debug 2.2.5 34 i686
up2date-gnome 2.7.86 7.x.3 i386
pciutils 2.1.9 2 i386
kdesdk-kompare 3.0.0 5 i386
pccts 1.33mr31 2 i386
kde-i18n-Romanian 3.0.0 5 noarch
recode 3.6 4 i386
xdelta 1.1.3 5 i386
PyQt 3.1 2 i386
qtcups 2.0 7 i386
python-devel 1.5.2 38 i386
dev86 0.15.5 1 i386
man-pages-it 0.3.0 7 noarch
curl 7.9.5 2 i386
Xaw3d 1.5 12 i386
kudzu-devel 0.99.52 1 i386
pspell 0.12.2 8 i386
mozilla-psm 0.9.9 7 i386
libxslt-python 1.0.15 1 i386
finger 0.17 9 i386
anonftp 4.0 9 i386
openmotif21 2.1.30 1 i386
vsftpd 1.0.1 5 i386
libpng 1.0.12 2 i386
libglade-devel 0.17 5 i386
kon2-fonts 0.3.9b 7 i386
sed 3.02 11 i386
qt2-Xt 2.3.1 3 i386
FreeWnn-common 1.11 20 i386
kmid 3.0.0 3 i386
xsane 0.84 2 i386
gnome-kerberos 0.3 4 i386
libgtop-devel 1.0.12 8 i386
libgal19 0.19.1 2 i386
iptables-ipv6 1.2.5 3 i386
gtk+-devel 1.2.10 15 i386
MyODBC 2.50.39 4 i386
psacct 6.3.2 19 i386
perl-TimeDate 1.10 14 i386
fetchmailconf 5.9.0 5 i386
wu-ftpd 2.6.2 5 i386
XFree86-S3 3.3.6 44 i386
db2 2.4.14 10 i386
karm 3.0.0 3 i386
ttfonts 1.0 9 noarch
rhn_register-gnome 2.7.21 7.x.3 i386
pygtk-devel 0.6.9 3 i386
cpio 2.4.2 26 i386
gtk2-devel 2.0.2 4 i386
psmisc 20.2 2 i386
perl-Archive-Tar 0.22 15 noarch
compat-egcs-objc 6.2 1.1.2.16 i386
fonts-ISO8859-2 1.0 3 noarch
setserial 2.17 5 i386
gtkhtml 1.0.2 1 i386
dia 0.88.1 3 i386
ash 0.3.7 2 i386
kde-i18n-Turkish 3.0.0 5 noarch
pygtk2-devel 1.99.8 7 i386
freetype-devel 2.0.9 2 i386
mtools 3.9.8 2 i386
gnome-lokkit 0.50 8 i386
libgtop-examples 1.0.12 8 i386
talk-server 0.17 12 i386
kdenetwork-libs 3.0.0 4 i386
kbdconfig 1.9.15 2 i386
redhat-switchmail 0.5.1 1 noarch
bg5ps 1.3.0 7 i386
lesstif-devel 0.93.18 2 i386
4Suite 0.11.1 8 i386
kdessh 3.0.0 4 i386
bzip2-libs 1.0.2 2 i386
cups-libs 1.1.14 15 i386
wine 20020327 1 i386
psgml 1.2.3 3 noarch
openldap12 1.2.13 3 i386
kWnn-devel 1.11 20 i386
XFree86-compat-modules 3.3.6 44 i386
watanabe-vf 1.0 5 noarch
balsa 1.2.4 1 i386
ruby-docs 1.6.7 2 i386
PyQt-examples 3.1 2 i386
libxml2-python 2.4.19 4 i386
kde-i18n-Afrikaans 3.0.0 5 noarch
kde-i18n-Italian 3.0.0 5 noarch
cleanfeed 0.95.7b 12 noarch
vorbis-tools 1.0rc3 3 i386
dump 0.4b27 3 i386
pwlib 1.2.12 3 i386
galeon 1.2.0 7 i386
libkscan-devel 3.0.0 5 i386
perl-XML-Grove 0.46alpha 11 noarch
nhpf 1.42 2 i386
nautilus-devel 1.0.6 15 i386
gnome-core 1.4.0.4 54 i386
rsh-server 0.17 5 i386
cWnn-devel 1.11 20 i386
ltrace 0.3.10 7 i386
console-tools 19990829 40 i386
ruby-mode-xemacs 1.6.7 2 i386
openh323-devel 1.8.0 3 i386
hotplug-gtk 2002_04_01 3 i386
patch 2.5.4 12 i386
macutils 2.0b3 19 i386
usermode 1.53 2 i386
Canna-devel 3.5b2 62 i386
XFree86-Xvfb 4.2.0 8 i386
gtkam 0.1.3 0.cvs20020225.2 i386
kde-i18n-Danish 3.0.0 5 noarch
perl-Devel-Symdump 2.01 15 i386
chkconfig 1.3.5 3 i386
gimp-devel 1.2.3 4 i386
man-pages-pl 0.22 7 noarch
perl-libnet 1.0901 17 i386
pkgconfig 0.12.0 1 i386
bash-doc 2.05a 13 i386
rpm-devel 4.0.4 7x.18 i386
chkfontpath 1.9.5 2 i386
netscape-communicator 4.79 1 i386
groff-gxditview 1.17.2 12 i386
compat-egcs-c++ 6.2 1.1.2.16 i386
glibc 2.2.5 34 i386
lrzsz 0.12.20 12 i386
cyrus-sasl-md5 1.5.24 25 i386
unixODBC 2.2.0 5 i386
samba-client 2.2.3a 6 i386
Guppi-devel 0.40.3 5 i386
anaconda-help 7.3 2 noarch
kdebindings-devel 3.0.0 1 i386
dip 3.3.7o 23 i386
gtk+10 1.0.6 10 i386
rpm2html 1.7 6 i386
mozilla-devel 0.9.9 7 i386
ftp 0.17 13 i386
kakasi-dict 2.3.4 3 i386
tclx 8.3 67 i386
kit 3.0.0 4 i386
pango 1.0.1 1 i386
mikmod 3.1.6 12 i386
kfile-pdf 3.0.0 5 i386
perl-DBD-Pg 1.01 8 i386
imap 2001a 10 i386
kde-i18n-Japanese 3.0.0 5 noarch
librep 0.15.1 3 i386
ee 0.3.12 5 i386
gdbm 1.8.0 14 i386
switchdesk-gnome 3.9.8 2 i386
kde-i18n-Norwegian 3.0.0 5 noarch
xdelta-devel 1.1.3 5 i386
kde-i18n-Czech 3.0.0 5 noarch
kuickshow 3.0.0 5 i386
dev 3.3 4 i386
gedit 0.9.7 8 i386
mod_roaming 1.0.2 4 i386
ruby-devel 1.6.7 2 i386
Omni-foomatic 0.5.1 3 i386
libpng-devel 1.0.12 2 i386
zlib 1.1.3 25.7 i386
libjpeg6a 6a 8 i386
mozilla-dom-inspector 0.9.9 7 i386
fonts-ISO8859-2-Type1 1.0 3 noarch
glibc-debug-static 2.2.5 34 i386
kmail 3.0.0 4 i386
mtx 1.2.16 2 i386
kxmlrpcd 3.0.0 4 i386
gd 1.8.4 4 i386
netpbm-devel 9.24 3 i386
grip 2.96 2 i386
openldap-servers 2.0.23 4 i386
sane-backends 1.0.7 6 i386
cyrus-sasl 1.5.24 25 i386
bind-devel 9.2.0 8 i386
xine-devel 0.9.8 4 i386
readline2.2.1 2.2.1 4 i386
qt2-static 2.3.1 3 i386
libgal7 0.8 7 i386
enscript 1.6.1 19 i386
gdk-pixbuf 0.14.0 8 i386
cdrdao 1.1.5 5 i386
python-docs 1.5.2 38 i386
rhmask 1.0 10 i386
gnome-pilot 0.1.64 3 i386
auth_ldap 1.6.0 4 i386
nss_db 2.2 14 i386
xpilot 4.4.3 5 i386
xsane-gimp 0.84 2 i386
Distutils 1.0.2 2 noarch
rootfiles 7.2 1 noarch
lilo 21.4.4 14 i386
w3c-libwww 5.3.2 5 i386
expat 1.95.2 2 i386
gnorpm 0.96 14 i386
kinput2-canna-wnn6 v3 14 i386
ucd-snmp-devel 4.2.4 3 i386
openh323 1.8.0 3 i386
gnome-applets 1.4.0.5 6 i386
caching-nameserver 7.2 1 noarch
parted 1.4.24 3 i386
perl-DateManip 5.40 15 i386
XFree86-SVGA 3.3.6 44 i386
xpdf 1.00 3 i386
postgresql 7.2.1 5 i386
wmclock 1.0.12.2 2 i386
nasm-doc 0.98.22 2 i386
cdlabelgen 1.5.0 11 noarch
xbill 2.0 16 i386
whois 1.0.10 1 i386
docbook-dtds 1.0 8 noarch
xsri 2.0.3 1 i386
gkrellm 1.2.9 1 i386
gftp 2.0.11 2 i386
mpage 2.5.1 9 i386
urw-fonts 2.0 17 noarch
inews 2.3.2 12 i386
tree 1.2 17 i386
mozilla-nss 0.9.9 7 i386
cracklib-dicts 2.7 15 i386
cups-drivers-hpijs 1.1 0.20020313.3 i386
sndconfig 0.68 1 i386
mc 4.5.55 5 i386
man-pages-es 1.28 1 noarch
openssh 3.1p1 3 i386
gtoaster 1.0beta5 2 i386
apmd 3.0.2 10 i386
expat-devel 1.95.2 2 i386
splint 3.0.1.6 2 i386
qt-devel 3.0.3 11 i386
cups 1.1.14 15 i386
cdparanoia-libs alpha9.8 8 i386
sysreport 1.3 2 noarch
ggv 1.0.2 4 i386
nautilus 1.0.6 15 i386
modutils 2.4.14 3 i386
XFree86-Mach8 3.3.6 44 i386
perl-libxml-enno 1.02 15 i386
kdesdk-kapptemplate 3.0.0 5 i386
mouseconfig 4.25 1 i386
micq 0.4.6.p1 2 i386
php-devel 4.1.2 7 i386
python 1.5.2 38 i386
mgetty-viewfax 1.1.28 3 i386
aspell-es 0.2 8 i386
libusb 0.1.5 3 i386
postgresql-odbc 7.2.1 5 i386
kernel-smp 2.4.18 3 athlon
nmh 1.0.4 9 i386
tetex-fonts 1.0.7 47 i386
mew 2.2 2 i386
mtr-gtk 0.49 1 i386
gnome-libs 1.4.1.2.90 14 i386
libole2-devel 0.2.4 1 i386
ImageMagick-c++-devel 5.4.3.11 1 i386
tmake 1.7 3 noarch
postfix 1.1.7 2 i386
kernel 2.4.18 3 athlon
guile 1.3.4 19 i386
krbafs-utils 1.1.1 1 i386
indexhtml 7.3 3 noarch
rarpd ss981107 9 i386
gated 3.6 14 i386
kfile-png 3.0.0 5 i386
newt-devel 0.50.35 1 i386
licq-kde 1.1.0 0.cvs20020416.1 i386
kaboodle 3.0.0 3 i386
mozilla-nspr 0.9.9 7 i386
postgresql-tcl 7.2.1 5 i386
lockdev-devel 1.0.0 16 i386
kde-i18n-Spanish 3.0.0 5 noarch
htdig 3.2.0 2.011302 i386
kterm 6.2.0 28 i386
gnome-vfs-extras 0.2.0 1 i386
kernel-bigmem 2.4.18 3 i686
pwlib-devel 1.2.12 3 i386
gnucash 1.6.6 3 i386
openssl-devel 0.9.6b 18 i386
ImageMagick-c++ 5.4.3.11 1 i386
XFree86-75dpi-fonts 4.2.0 8 i386
rhn-applet 1.0.6 11 noarch
glibc-kernheaders 2.4 7.14 i386
wl 2.8.1 5 noarch
kdeartwork-kworldclock 3.0.0 4 i386
mod_bandwidth 2.0.3 3 i386
rep-gtk 0.15 7 i386
perl-XML-Twig 2.02 9 noarch
giftrans 1.12.2 11 i386
lockdev 1.0.0 16 i386
kdvi 3.0.0 5 i386
smpeg-xmms 0.3.4 6 i386
texinfo 4.1 1 i386
slocate 2.6 1 i386
authconfig-gtk 4.2.8 4 i386
lapack-man 3.0 14 i386
libsigc++-devel 1.0.3 5 i386
Maelstrom 3.0.1 18 i386
kde-i18n-Hebrew 3.0.0 5 noarch
statserial 1.1 27 i386
kcharselect 3.0.0 4 i386
gmp-devel 4.0.1 3 i386
gtkam-gimp 0.1.3 0.cvs20020225.2 i386
pam-devel 0.75 32 i386
gnome-audio 1.4.0 1 noarch
ksconfig 2.0 7 noarch
fonts-ISO8859-2-100dpi 1.0 3 noarch
perl-MIME-Base64 2.12 14 i386
gnomemeeting 0.85.1 3 i386
kernel-BOOT 2.4.18 3 i386
zsh 4.0.4 5 i386
libaio-devel 0.3.12 1 i386
indent 2.2.7 3 i386
pydict 0.2.5.1 8 noarch
apacheconf 0.8.2 2 noarch
hdparm 4.6 1 i386
lv 4.49.4 3 i386
db1-devel 1.85 8 i386
irb 1.6.7 2 i386
SDL-devel 1.2.3 7 i386
mt-st 0.7 3 i386
xboard 4.2.3 2 i386
awesfx 0.4.3a 8 i386
pdksh 5.2.14 16 i386
webalizer 2.01_10 1 i386
anaconda-images 7.3 6 noarch
ncurses-c++-devel 5.2 26 i386
perl-suidperl 5.6.1 34.99.6 i386
XFree86-ISO8859-15-100dpi-fonts 4.2.0 8 i386
passivetex 1.12 3 noarch
knotes 3.0.0 3 i386
openssl 0.9.6b 18 i686
xsnow 1.42 3 i386
glibc-devel 2.2.5 34 i386
redhat-config-users 1.0.1 5 noarch
SysVinit 2.84 2 i386
gdk-pixbuf-gnome 0.14.0 8 i386
XFree86-base-fonts 4.2.0 8 i386
telnet-server 0.17 20 i386
mysqlclient9 3.23.22 6 i386
ypserv 2.2 9 i386
gdb 5.1.90CVS 5 i386
xloadimage 4.1 21 i386
tftp 0.28 2 i386
kdelibs 3.0.0 10 i386
libxml 1.8.17 3 i386
autoconf253 2.53 3 noarch
sharutils 4.2.1 9 i386
xcpustate 2.5 11 i386
cdparanoia alpha9.8 8 i386
vim-minimal 6.1 2 i386
wl-common 2.8.1 5 noarch
bison 1.35 1 i386
db1 1.85 8 i386
libtermcap-devel 2.0.8 28 i386
perl-Digest-MD5 2.16 15 i386
db2-devel 2.4.14 10 i386
gphoto2-devel 2.0 4 i386
radvd 0.7.1 1 i386
ddd 3.3.1 13 i386
skkinput 2.03 9 i386
semi 1.14.3 11 noarch
hotplug 2002_04_01 3 i386
aspell-en-gb 0.33.7.1 9 i386
libglade 0.17 5 i386
dos2unix 3.1 10 i386
kview 3.0.0 5 i386
libtool-libs13 1.3.5 2 i386
nkf 1.92 6 i386
kdeaddons-kicker 3.0.0 4 i386
libungif 4.1.0 10 i386
eel 1.0.2 11 i386
gtk-doc 0.5.9 1 noarch
nvi-m17n 1.79 20011024.2 i386
kpaint 3.0.0 5 i386
stat 2.5 5 i386
libtermcap 2.0.8 28 i386
XFree86-S3V 3.3.6 44 i386
extace 1.5.1 3 i386
openjade 1.3.1 4 i386
mkxauth 1.7 18 noarch
logrotate 3.6.4 1 i386
kde-i18n-Dutch 3.0.0 5 noarch
quota 3.03 1 i386
perl-HTML-Parser 3.26 2 i386
hwbrowser 0.3.8 1 noarch
asp2php 0.76.2 1 i386
libgtkhtml9 0.9.2 10 i386
libgnomeprint15 0.35 4 i386
mew-xemacs 2.2 2 i386
mm 1.1.3 4 i386
switchdesk-kde 3.9.8 2 i386
libstdc++ 2.96 110 i386
kdesdk-kspy 3.0.0 5 i386
fonts-KOI8-R 1.0 1 noarch
aspell-en-ca 0.33.7.1 9 i386
pcre-devel 3.9 2 i386
kontrol-panel 4.2.3 2 i386
libdbi-dbd-mysql 0.6.4 2 i386
kdeaddons-konqueror 3.0.0 4 i386
kernel-source 2.4.18 3 i386
logwatch 2.6 2 noarch
XFree86-3DLabs 3.3.6 44 i386
smpeg 0.4.4 9 i386
kcoloredit 3.0.0 5 i386
xlockmore 4.17.2 5 i386
man-pages-fr 0.9 5 noarch
sawfish 1.0.1 9 i386
x3270-text 3.2.18 2 i386
mozilla-nspr-devel 0.9.9 7 i386
nmap 2.54BETA31 1 i386
libvorbis 1.0rc3 1 i386
mod_python 2.7.6 5 i386
tkinter2 2.2 16 i386
jadetex 3.12 2 noarch
procps-X11 2.0.7 12 i386
minicom 2.00.0 3 i386
xml-common 0.6.3 9 noarch
kde-i18n-Ukrainian 3.0.0 5 noarch
samba-common 2.2.3a 6 i386
xmltex 20000118 8 noarch
m4 1.4.1 7 i386
info 4.1 1 i386
pygtk2-libglade 1.99.8 7 i386
iproute 2.4.7 1 i386
wmapm 1.1 1 i386
lesstif 0.93.18 2 i386
rusers 0.17 12 i386
WindowMaker 0.80.0 9 i386
kdegames 3.0.0 2 i386
pmake 1.45 4 i386
sawfish-themer 1.0.1 9 i386
wget 1.8.1 4 i386
stunnel 3.22 1 i386
blas 3.0 14 i386
db3-utils 3.3.11 6 i386
mod_dav 1.0.3 5 i386
glib2-devel 2.0.1 2 i386
freetype-demos 2.0.9 2 i386
flim 1.14.3 4 noarch
FreeWnn-devel 1.11 20 i386
Canna-libs 3.5b2 62 i386
ncpfs 2.2.0.18 6 i386
iputils 20020124 3 i386
bzip2-devel 1.0.2 2 i386
xalf 0.11 5 i386
libkscan 3.0.0 5 i386
readline-devel 4.2a 4 i386
fam 2.6.7 6 i386
libole2 0.2.4 1 i386
jisksp16-1990 0.1 6 noarch
unixODBC-devel 2.2.0 5 i386
sox 12.17.3 4 i386
python-tools 1.5.2 38 i386
openssh-askpass 3.1p1 3 i386
h2ps 2.06 2 i386
XFree86-cyrillic-fonts 4.2.0 8 i386
nscd 2.2.5 34 i386
magicdev 0.3.6 6 i386
smpeg-devel 0.4.4 9 i386
rcs 5.7 15 i386
routed 0.17 8 i386
libao-devel 0.8.2 2 i386
fileutils 4.1 10 i386
pinfo 0.6.4 4 i386
kdeartwork 3.0.0 4 i386
imap-devel 2001a 10 i386
libghttp-devel 1.0.9 2 i386
gnumeric-devel 1.0.5 3 i386
knode 3.0.0 4 i386
glms 1.03 14 i386
python-popt 0.8.8 7.x.2 i386
raidtools 1.00.2 1.3 i386
kamera 3.0.0 5 i386
abiword 0.99.5 1 i386
slang-devel 1.4.5 2 i386
scrollkeeper 0.3.4 4 i386
man-pages-da 0.1.1 4 noarch
Xconfigurator 4.10.7 1 i386
apache-manual 1.3.23 11 i386
xdaliclock 2.18 8 i386
redhat-release 7.3 1 noarch
lynx 2.8.4 18 i386
htmlview 2.0.0 1 noarch
initscripts 6.67 1 i386
atk 1.0.1 1 i386
ddskk-xemacs 11.6.0 6 noarch
glib 1.2.10 5 i386
ttcp 1.12 2 i386
zip 2.3 12 i386
cdecl 2.5 22 i386
pxe 0.1 24 i386
kdeadmin 3.0.0 4 i386
bridge-utils 0.9.3 4 i386
passwd 0.67 1 i386
nvi-m17n-canna 1.79 20011024.2 i386
fetchmail 5.9.0 5 i386
gnome-vfs 1.0.5 4 i386
joystick 1.2.15 11 i386
gnome-games 1.4.0.1 5 i386
gnome-print-devel 0.35 4 i386
gnome-audio-extra 1.4.0 1 noarch
bc 1.06 8 i386
Guppi 0.40.3 5 i386
w3m-el 1.2.6 1 i386
autorun 2.73 1 i386
XFree86-libs 4.2.0 8 i386
sendmail-doc 8.11.6 15 i386
control-center 1.4.0.1 31 i386
gkermit 1.0 9 i386
switchdesk 3.9.8 2 i386
sendmail-cf 8.11.6 15 i386
a2ps 4.13b 19 i386
freetype-utils 2.0.9 2 i386
gzip 1.3.3 1 i386
compat-libs 6.2 3 i386
gimp 1.2.3 4 i386
procmail 3.22 5 i386
gcc-g77 2.96 110 i386
rpm-python 4.0.4 7x.18 i386
isdn4k-utils-vboxgetty 3.1 53 i386
pygtk2 1.99.8 7 i386
libstdc++-devel 2.96 110 i386
perl-BSD-Resource 1.14 11 i386
gtk2 2.0.2 4 i386
umb-scheme 3.2 21 i386
samba 2.2.3a 6 i386
fvwm2 2.4.6 1 i386
hexedit 1.2.2 3 i386
php-dbg 4.1.2 7 i386
findutils 4.1.7 4 i386
perl-Storable 1.0.14 15 i386
kiconedit 3.0.0 5 i386
man-pages-de 0.4 1 noarch
hpijs 1.0.2 8 i386
kde-i18n-French 3.0.0 5 noarch
mysql 3.23.49 3 i386
gnome-utils 1.4.0 9 i386
fonts-ISO8859-7-75dpi 1.0 2 noarch
perl-XML-Parser 2.30 15 i386
itcl 3.2 67 i386
nfs-utils 0.3.3 5 i386
MagicPoint 1.09a 1 i386
file 3.37 5 i386
php-snmp 4.1.2 7 i386
sendmail-devel 8.11.6 15 i386
redhat-config-network 1.0.0 1 i386
ethereal 0.9.3 3 i386
plugger 4.0 6 i386
gettext 0.11.1 2 i386
irda-utils 0.9.14 3 i386
which 2.13 3 i386
kedit 3.0.0 4 i386
mod_ssl 2.8.7 4 i386
autoconvert 0.3.7 6 i386
kernel-utils 2.4 7.4 i386
Wnn6-SDK 1.0 18 i386
sliplogin 2.1.1 12 i386
utempter 0.5.2 6 i386
gphoto 0.4.3 17 i386
inn 2.3.2 12 i386
postgresql-libs 7.2.1 5 i386
Wnn6-SDK-devel 1.0 18 i386
dhcp 2.0pl5 8 i386
jisksp14 0.1 7 noarch
kmidi 3.0.0 3 i386
bonobo-conf-devel 0.14 5 i386
XFree86-AGX 3.3.6 44 i386
XFree86-ISO8859-15-75dpi-fonts 4.2.0 8 i386
libaio 0.3.12 1 i386
lsof 4.51 2 i386
krb5-libs 1.2.4 1 i386
sysstat 4.0.3 2 i386
nut-cgi 0.45.4 1 i386
libdbi-dbd-pgsql 0.6.4 2 i386
usbutils 0.9 5 i386
ypbind 1.10 7 i386
libcap-devel 1.10 8 i386
inn-devel 2.3.2 12 i386
w3c-libwww-devel 5.3.2 5 i386
libxslt-devel 1.0.15 1 i386
quanta 2.1 0.cvs20020404.2 i386
perl-Frontier-RPC 0.06 14 i386
pcre 3.9 2 i386
koffice-devel 1.1.1 5 i386
strace 4.4 4 i386
libxml-devel 1.8.17 3 i386
PyXML 0.7 4 i386
arpwatch 2.1a11 12 i386
gdbm-devel 1.8.0 14 i386
LPRng 3.8.9 3 i386
dejagnu 1.4.2 3 noarch
cdrecord 1.10 11 i386
filesystem 2.1.6 2 noarch
time 1.7 16 i386
shapecfg 2.2.12 8 i386
xmms 1.2.7 1 i386
tetex-latex 1.0.7 47 i386
ttfprint 0.9 1 i386
binutils 2.11.93.0.2 11 i386
jcode.pl 2.13 2 noarch
pciutils-devel 2.1.9 2 i386
fam-devel 2.6.7 6 i386
gimp-data-extras 1.2.0 4 noarch
mpg321 0.2.9 3 i386
cdp 0.33 22 i386
XFree86-devel 4.2.0 8 i386
wvdial 1.41 16 i386
kernel-smp 2.4.18 3 i586
gnome-media 1.2.3 4 i386
rsync 2.5.4 2 i386
gmp 4.0.1 3 i386
XFree86-compat-libs 4.0.3 2 i386
XFree86-xtrap-clients 4.2.0 8 i386
qt-MySQL 3.0.3 11 i386
grep 2.5.1 1 i386
xine 0.9.8 4 i386
anaconda-runtime 7.3 7 i386
licq-text 1.1.0 0.cvs20020416.1 i386
gtop 1.0.13 4 i386
gimp-perl 1.2.3 4 i386
genromfs 0.3 9 i386
tar 1.13.25 4 i386
kde-i18n-Korean 3.0.0 5 noarch
usermode-gtk 1.53 2 i386
kde-i18n-Serbian 3.0.0 5 noarch
aspell-de 0.1.1 12 i386
bind-utils 9.2.0 8 i386
gnome-user-docs 1.4.1 1 noarch
