#!/usr/bin/perl -w
use esmith::rpm::filename qw/regex/;
use Test::More 'no_plan';

my @rpms;
while(my $line = <DATA>)
{
    next if ($line =~ /^(?:#.*)?\s*$/);
    push @rpms, [ split(/\s+/,$line,-1) ];  
}

foreach my $rpm (@rpms)
{
    my ($n,$v,$r,$a) = @$rpm;
    is($n eq ($n =~ /^$RE_N$/)[0], 1,"$n".' =~ /^$RE_N$/');
    is($v eq ($v =~ /^$RE_V$/)[0], 1,"$v".' =~ /^$RE_V$/');
    is($r eq ($r =~ /^$RE_R$/)[0], 1,"$r".' =~ /^$RE_R$/');
    is_deeply(["$n-$v" =~ /^$RE_NV$/], [$n,$v], 
	    "$n-$v".' =~ /^$RE_NV$/');
    is_deeply(["$v-$r" =~ /^$RE_VR$/], [$v,$r], 
	    "$v-$r".' =~ /^$RE_VR$/');
    is_deeply(["$n-$v-$r" =~ /^$RE_NVR$/], [$n,$v,$r],
	    "$n-$v-$r".' =~ /^$RE_NVR$/');
    is_deeply(["$n-$v-$r.$a" =~ /^$RE_NVRARCH$/], [$n,$v,$r,$a],
	    "$n-$v-$r.$a".' =~ /^$RE_NVRARCH$/');
    is_deeply(["$n-$v-$r.$a.rpm" =~ /^$RE_FILENAME$/], [$n,$v,$r,$a,'rpm'],
	    "$n-$v-$r.$a.rpm".' =~ /^$RE_FILENAME$/');
    is_deeply(["$n-$v-$r.$a.rpm" =~ /^$RE_NVRARCH(?:\.$RE_EXT)?$/], 
			[$n,$v,$r,$a,'rpm'],
	    "$n-$v-$r.$a.rpm".' =~ /^$RE_NVRARCH(?:\.$RE_EXT)$/');
    is_deeply(["$n-$v-$r.src.rpm" =~ /^$RE_FILENAME$/],
			[$n,$v,$r,undef,'src.rpm'],
	    "$n-$v-$r.src.rpm".' =~ /^$RE_FILENAME$/');
    is_deeply(["$n-$v-$r.src.rpm" =~ /^$RE_NVR(?:$RE_ARCH)?(?:\.$RE_EXT)?$/], 
			[$n,$v,$r,undef,'src.rpm'],
	    "$n-$v-$r.src.rpm".' =~ /^$RE_NVR(?:\.$RE_ARCH(?:\.$RE_EXT)?)?$/');
    is_deeply(["$n-$v-$r.$a.src.rpm" =~ /^$RE_FILENAME$/],
			[$n,$v,$r,$a,'src.rpm'],
	    "$n-$v-$r.$a.src.rpm".' =~ /^$RE_FILENAME$/');
    is_deeply(["$n-$v-$r.$a.src.rpm" =~ /^$RE_NVR(?:\.$RE_ARCH)?(?:\.$RE_EXT)?$/], 
			[$n,$v,$r,$a,'src.rpm'],
	    "$n-$v-$r.$a.src.rpm".' =~ /^$RE_NVR(?:\.$RE_ARCH(?:\.$RE_EXT)?)?$/');
}

__DATA__
# RPMs found in /home/e-smith/files/ibays/development/files/projects/e--
# smith-releases/5.5rc2+SL on Thu Aug 22 16:43:26 2002
ServiceLink-scanner 1.2.0 01 noarch
netatalk 1.5.2 2 i386
ncompress 4.2.4 24 i386
taper 6.9b 4 i386
e-smith-release 5.5 02 noarch
ServiceLink-freeswan 1.8.0 01 noarch
bzip2-libs 1.0.1 4 i386
freetype 2.0.3 7 i386
perl-perl-ldap 0.22 10 i386
perl-Text-Iconv 1.2 1 i386
perl-Text-Wrapper 1.000 10 i386
perl-XML-Parser 2.30 7 i386
kernel 2.2.19 7.0.8 i586
e-smith-turba 0.20.0 01 noarch
e-smith-base 4.10.5 01 noarch
kudzu 0.72 7es i386
samba-common 2.2.4 3 i386
dump 0.4b25 1.72.1es i386
mod_auth_external 2.1.2 6 i386
perl-CGI 2.752 26.72.3 i386
kernel-smp 2.2.19 7.0.8 i586
e-smith-horde 1.4.12 01 noarch
mutt 1.2.5.1 1 i386
mkinitrd 3.0.10 1 i386
stat 2.5 2 i386
perl-MIME-Base64 2.12 6 i386
buffer 1.19 5 i386
perl-Error 0.14 01 i386
glibc 2.2.4 24 i686
ip_masq_icq 0.56 9 i386
wget 1.7 3 i386
e-smith-wu-imap 1.4.0 01 noarch
isapnptools 1.22 5 i386
libtool-libs 1.4 8 i386
procps 2.0.7 11 i386
ed 0.2 21 i386
e-smith-dynamicdns-yi 1.2.3 01 noarch
LPRng 3.7.4 28 i386
perl-URI 1.11 2 i386
freeswan 1.97 07 i386
db2 2.4.14 7 i386
e-smith-quota 1.4.0 01 noarch
perl-libwww-perl 5.48 10 i386
e-smith-apache-proxy 0.0.4 01 noarch
patch 2.5.4 10 i386
flexbackup 0.9.8 06es noarch
vim-enhanced 6.0 7.13 i386
cyrus-sasl-md5 1.5.24 23 i386
rpm-build 4.0.4 7x i386
ServiceLink-activation 1.2.0 02 noarch
pidentd 2.8.5 3+masq i386
glibc-common 2.2.4 24 i386
mt-st 0.6 1 i386
bc 1.06 5 i386
apache 1.3.22 3.7.1es i386
e-smith-dynamicdns-dyndns 1.2.3 01 noarch
e-smith-lilo 1.8.0 01 noarch
cyrus-sasl 1.5.24 23 i386
findutils 4.1.7 1 i386
kernel 2.2.19 7.0.8 i686
tnef 1.1.1 1 i386
e-smith-dynamicdns-dyndns.org 1.2.3 01 noarch
e-smith-manager 1.6.0 01 noarch
kernel-smp 2.2.19 7.0.8 i686
apmd 3.0final 29 i386
isdn4k-utils 3.1 39 i386
perl-CGI-Persistent 0.22 2 i386
perl-HTML-Tagset 3.03 10 i386
mingetty 0.9.4 18 i386
gmp 3.1.1 4 i386
horde 2.0 5es noarch
kernel-pcmcia-cs 2.2.19 7.0.8 i386
e-smith-LPRng 1.6.7 01 noarch
e-smith-openssh 1.6.0 01 noarch
e-smith-ldap 4.6.0 01 noarch
perl-CGI-FormMagick 0.85 03 i386
mount 2.11g 5 i386
newt 0.50.18 04es i386
basesystem 7.0 2 noarch
lockdev 1.0.0 14 i386
ncurses4 5.0 5 i386
ServiceLink-registration 1.6.2 01 noarch
perl-Quota 1.4 2 i386
kbdconfig 1.9.14 1 i386
perl-Authen-PAM 0.12 1 i386
ServiceLink 5.5 03 noarch
pptpd 1.1.2 2 i386
anacron 2.3 17 i386
eject 2.0.9 2 i386
ServiceLink-lib 1.2.0 01 noarch
util-linux 2.11f 17 i386
net-tools 1.60 3 i386
e-smith-email 4.10.0 01 noarch
megaide 1.03d 02 i386
cracklib 2.7 12 i386
openssh-server 3.1p1 2 i386
php-imap 4.1.2 2es3 i386
at 3.1.8 23 i386
e-smith-netatalk 1.8.1 01 noarch
cvs 1.11.1p1 7es1 i386
kernel-utils 2.2.19 7.0.8 i386
php-ldap 4.1.2 2es3 i386
minicom 1.83.1 16 i386
popt 1.6.4 7x i386
sysklogd 1.4.1 4 i386
telnet 0.17 20 i386
ucspi-tcp 0.88 03 i386
sash 3.4 11 i386
imap 4.7 1mdir10es i386
e-smith-keys 1.2.0 02 noarch
bdflush 1.5 17 i386
diald-top 2.1pl4 2es i386
mm 1.1.3 2 i386
perl-Convert-ASN1 0.07 10 i386
python2 2.2 16 i386
tcsh 6.10 6 i386
sed 3.02 10 i386
pspell 0.12.2 3 i386
perl-Text-Template 1.43 1 i386
xinetd 2.3.3 1 i386
php-mysql 4.1.2 2es3 i386
dhcpcd 1.3.18pl8 13 i386
strace 4.3 2 i386
wireless-tools 21 3 i386
e-smith-proxy 4.8.0 01 noarch
initscripts 5.83 1es4 i386
raidtools 0.90 24 i386
setserial 2.17 4 i386
mailfront 0.74 1 i386
libxml2 2.4.10 0.7x.2 i386
crontabs 1.10 1 noarch
words 2 17 noarch
e-smith-mysql 1.6.0 01 noarch
perl-DBI 1.21 1 i386
fastforward 0.51 03 i386
perl-Filter-Handle 0.03 10 i386
console-tools 19990829 36 i386
gzip 1.3 12 i586
samba-client 2.2.4 3 i386
qmail 1.03 06 i386
dot-forward 0.71 02 i386
termcap 11.0.1 10 noarch
ip_masq_h323 2.2.0 01 i386
ftp 0.17 12 i386
freeswan 1.97 07 i586
tcp_wrappers 7.6 19 i386
e-smith-qmail 1.4.0 01 noarch
man 1.5i2 6 i386
pciutils 2.1.8 23 i386
perl-gettext 1.01 10 i386
mc 4.5.51 36 i386
ServiceLink-dns 1.6.1 01 noarch
krb5-libs 1.2.2 13 i386
openssl 0.9.6b 8 i386
e-smith-daemontools 1.2.0 03 noarch
libcap 1.10 5 i386
hdparm 4.1 2 i386
db3 3.2.9 4 i386
shadow-utils 20000902 4 i386
openssh 3.1p1 2 i386
slang 1.4.4 4 i386
ispell 3.1.20 27 i386
trendVirusWall 3.6 03 i386
mailx 8.1.1 22 i386
perl-Test-Harness-Straps 0.10 1 noarch
diald 0.99.4 2 i386
time 1.7 14 i386
info 4.0b 3 i386
e-smith-formmagick 0.2.0 01 noarch
perl-Digest-SHA1 2.01 1 i386
psmisc 20.1 2 i386
e-smith-proftpd 1.6.0 01 noarch
e-smith-reinstall-floppy 1.8.0 01 noarch
e-smith-viewlogfiles 1.0.5 01 noarch
sshell 2.1 04 i386
rp-pppoe 2.6 5es i386
syslinux 1.52 2 i386
autopassword 2.0 3 i386
e-smith-hosts 1.8.6 01 noarch
e-smith-qmailanalog 1.6.0 01 noarch
e-smith-pptpd 1.4.5 01 noarch
mysql 3.23.41 1 i386
SMEServer 5.5 01 noarch
quota 2.00pre3 7es i386
perl 5.6.1 26.72.3 i386
perl-CPAN 1.59_54 26.72.3 i386
mkbootdisk 1.4.3 1es i386
e-smith-blades 1.4.0 01 noarch
db1 1.85 7 i386
ipchains 1.3.10 10 i386
compat-libstdc++ 6.2 2.9.0.16 i386
ipmasqadm 0.4.2 4es i386
openldap-clients 2.0.21 1 i386
iputils 20001110 6 i386
freeswan 1.97 07 i686
rpm-perl 4.0.4 7x i386
bzip2 1.0.1 4 i386
tai64nunix 0.70 03 i386
ip_masq_rtsp 0.91 01 i386
libstdc++ 2.96 98 i386
pine 4.44 1.72.0 i386
bash 2.05 8 i386
openldap 2.0.21 1 i386
e-smith-imp 1.6.9 01 noarch
libpng 1.0.12 2 i386
bind-utils 9.1.3 4 i386
MAKEDEV 3.2 5 i386
losetup 2.11g 5 i386
perl-Crypt-SSLeay 0.25 1 i386
e-smith-packetfilter 1.8.0 01 noarch
e-smith-samba 1.6.2 01 noarch
perl-DBD-MySQL 1.2216 4 i386
passwd 0.64.1 7 i386
ServiceLink-antivirus-trend 1.6.2 01 noarch
e-smith-rp-pppoe 1.6.0 01 noarch
ash 0.3.7 2 i386
mtools 3.9.8 2 i386
sh-utils 2.0.11 5 i386
daemontools 0.70 05 i386
perl-Test-Inline 0.14 1 i386
vim-common 6.0 7.13 i386
pwdb 0.61.1 3 i386
e2fsprogs 1.26 1.72 i386
mktemp 1.5 11 i386
pam 0.75 19 i386
supervise-scripts 3.3 1es1 noarch
e-smith-lib 1.10.2 01 noarch
e-smith-boot-image 1.6.3 01 noarch
lynx 2.8.4 17 i386
logrotate 3.5.9 1 i386
e-smith-backup 1.8.2 01 noarch
urlview 0.9 2 i386
ntsysv 1.2.24 1 i386
glibc 2.2.4 24 i386
perl-Time-HiRes 01.20 10 i386
readline 4.2 2 i386
e-smith-test 0.2.0 01 noarch
gdbm 1.8.0 10 i386
mysql-server 3.23.41 1 i386
vim-minimal 6.0 7.13 i386
e-smith-telnet 1.2.0 05 noarch
zlib 1.1.3 25.7 i386
sharutils 4.2.1 8.7.x i386
gd 1.8.4 4 i386
checkpassword 0.90 02 i386
perl-Clone 0.13 1 i386
e-smith-proxypass 1.0.0 01 noarch
tar 1.13.19 6 i386
rootfiles 7.2 1 noarch
lilo 21.4.4 14 i386
mod_perl 1.26 2 i386
samba 2.2.4 3 i386
openldap-servers 2.0.21 1 i386
perl-Object-Persistence 0.92 2 i386
e-smith-flexbackup 1.4.0 01 noarch
perl-HTML-Parser 3.25 2 i386
libjpeg 6b 16 i386
shapecfg 2.2.12 7 i386
diffutils 2.7.2 2 i386
perl-WWW-Automate 0.20 1 i386
mod_ssl 2.8.5 4 i386
tcl 8.3.3 65 i386
e-smith-rpm 0.0.24 01 noarch
perl-MailTools 1.40 1 i386
slocate 2.6 1 i386
less 358 21 i386
kernel 2.2.19 7.0.8 i386
e-smith-named 1.8.0 01 noarch
textutils 2.0.11 7 i386
indexhtml 7.2 1 noarch
e-smith-dynamicdns-tzo 1.2.0 04 noarch
kernel-smp 2.2.19 7.0.8 i386
openssh-clients 3.1p1 2 i386
fileutils 4.1 4 i386
perl-Class-ParamParser 1.0401 1 i386
perl-NDBM_File 1.75 26.72.3 i386
telnet-server 0.17 20 i386
mysqlclient9 3.23.22 6 i386
setup 2.5.7 01es noarch
binutils 2.11.90.0.8 12 i386
rmt 0.4b25 1.72.0 i386
mailcap 2.1.6 1 noarch
dev 3.2 5 i386
rpm 4.0.4 7x i386
whois 1.0.9 1 i386
perl-Crypt-Cracklib 0.01 1 i386
ServiceLink-keys 1.4.1 01 noarch
procmail 3.21 1 i386
ncurses 5.2 12 i386
libtermcap 2.0.8 28 i386
e-smith-php 1.6.0 01 noarch
expat 1.95.1 7 i386
ServiceLink-support 1.8.0 01 noarch
traceroute 1.4a12 1 i386
ServiceLink-email 1.4.0 01 noarch
which 2.12 3 i386
gpm 1.19.3 20 i386
e-smith-mailfront 0.2.0 01 noarch
groff 1.17.2 7.0.2 i386
gzip 1.3 15 i386
perl-DB_File 1.75 26.72.3 i386
grep 2.4.2 7 i386
proftpd 1.2.0rc3 2es i386
bind 9.1.3 4 i386
ntp 4.1.0 4 i386
cpio 2.4.2 23 i386
stunnel 3.22 1 i386
libsmbpw 1.1 3 i386
php-pgsql 4.1.2 2es3 i386
perl-Test-Simple 0.42 1 i386
ppp 2.4.0 12 i386
e-smith-ntp 1.8.0 01 noarch
vixie-cron 3.0.1 63 i386
fetchmail 5.9.0 11 i386
modutils 2.4.13 0.7.1 i386
rcs 5.7 15 i386
e-smith-devtools 1.8.0 01 noarch
perl-FreezeThaw 0.41 10 i386
sudo 1.6.5p2 1.7x.1 i386
gnupg 1.0.6 3 i386
glib 1.2.10 5 i386
turba 1.0 6es noarch
dosfstools 2.7 1 i386
gawk 3.1.0 3 i386
e-smith-locale-fr_CA 1.2.3 01 noarch
qmailanalog 0.70 03 i386
tmpwatch 2.8.1 1 i386
iproute 2.2.4 14 i386
perl-Digest-MD5 2.13 1 i386
db31 3.1.17 1 i386
e-smith 4.2.0 06 noarch
perl-I18N-LangTags 0.13 10 i386
tcpdump 3.6.2 11.7.2.0 i386
utempter 0.5.2 6 i386
imp 3.0 4es noarch
dhcp 2.0pl5 8 i386
ServiceLink-branding 1.4.0 02 noarch
php 4.1.2 2es3 i386
cracklib-dicts 2.7 12 i386
lsof 4.51 2 i386
authconfig 4.1.19.2 1 i386
SysVinit 2.78 19 i386
filesystem 2.1.6 2 noarch
file 3.35 2 i386
e-smith-ipmasq 1.6.0 01 noarch
python 1.5.2 35 i386
maildrop 1.3.0 1.7.0 i386
chkconfig 1.2.24 1 i386
mysql-devel 3.23.41 1 i386
ServiceLink-locale-fr_CA 1.2.1 01 noarch
rsync 2.5.4 2 i386
unzip 5.42 1 i386
squid 2.4.STABLE3 1.7.2 i386
