#!/usr/bin/perl -w
use esmith::rpm::filename qw/regex/;
use Test::More 'no_plan';

my @rpms;
while(my $line = <DATA>)
{
    next if ($line =~ /^(?:#.*)?\s*$/);
    push @rpms, [ split(/\s+/,$line,-1) ];  
}

foreach my $rpm (@rpms)
{
    my ($n,$v,$r,$a) = @$rpm;
    is($n eq ($n =~ /^$RE_N$/)[0], 1,"$n".' =~ /^$RE_N$/');
    is($v eq ($v =~ /^$RE_V$/)[0], 1,"$v".' =~ /^$RE_V$/');
    is($r eq ($r =~ /^$RE_R$/)[0], 1,"$r".' =~ /^$RE_R$/');
    is_deeply(["$n-$v" =~ /^$RE_NV$/], [$n,$v], 
	    "$n-$v".' =~ /^$RE_NV$/');
    is_deeply(["$v-$r" =~ /^$RE_VR$/], [$v,$r], 
	    "$v-$r".' =~ /^$RE_VR$/');
    is_deeply(["$n-$v-$r" =~ /^$RE_NVR$/], [$n,$v,$r],
	    "$n-$v-$r".' =~ /^$RE_NVR$/');
    is_deeply(["$n-$v-$r.$a" =~ /^$RE_NVRARCH$/], [$n,$v,$r,$a],
	    "$n-$v-$r.$a".' =~ /^$RE_NVRARCH$/');
    is_deeply(["$n-$v-$r.$a.rpm" =~ /^$RE_FILENAME$/], [$n,$v,$r,$a,'rpm'],
	    "$n-$v-$r.$a.rpm".' =~ /^$RE_FILENAME$/');
    is_deeply(["$n-$v-$r.$a.rpm" =~ /^$RE_NVRARCH(?:\.$RE_EXT)?$/], 
			[$n,$v,$r,$a,'rpm'],
	    "$n-$v-$r.$a.rpm".' =~ /^$RE_NVRARCH(?:\.$RE_EXT)$/');
    is_deeply(["$n-$v-$r.src.rpm" =~ /^$RE_FILENAME$/],
			[$n,$v,$r,undef,'src.rpm'],
	    "$n-$v-$r.src.rpm".' =~ /^$RE_FILENAME$/');
    is_deeply(["$n-$v-$r.src.rpm" =~ /^$RE_NVR(?:$RE_ARCH)?(?:\.$RE_EXT)?$/], 
			[$n,$v,$r,undef,'src.rpm'],
	    "$n-$v-$r.src.rpm".' =~ /^$RE_NVR(?:\.$RE_ARCH(?:\.$RE_EXT)?)?$/');
    is_deeply(["$n-$v-$r.$a.src.rpm" =~ /^$RE_FILENAME$/],
			[$n,$v,$r,$a,'src.rpm'],
	    "$n-$v-$r.$a.src.rpm".' =~ /^$RE_FILENAME$/');
    is_deeply(["$n-$v-$r.$a.src.rpm" =~ /^$RE_NVR(?:\.$RE_ARCH)?(?:\.$RE_EXT)?$/], 
			[$n,$v,$r,$a,'src.rpm'],
	    "$n-$v-$r.$a.src.rpm".' =~ /^$RE_NVR(?:\.$RE_ARCH(?:\.$RE_EXT)?)?$/');
}

__DATA__
# RPMs found in /home/e-smith/files/ibays/development/files/projects/e--
# smith-releases/5.6alpha7/cdrom.image/e-smith/RPMS/ on Thu Aug 22
# 16:44:13 2002
ncompress 4.2.4 28 i386
e-smith-proxypass 1.1.0 01 noarch
e-smith-dynamicdns-dyndns 1.3.0 01 noarch
libuser 0.50.2 1 i386
e-smith-openssh 1.7.3 01 noarch
perl 5.6.1 34.99.6 i386
perl-perl-ldap 0.22 10 i386
perl-Text-Iconv 1.2 1 i386
perl-CPAN 1.59_54 34.99.6 i386
make 3.79.1 8 i386
dosfstools 2.8 1 i386
e-smith-dynamicdns-dyndns.org 1.3.0 01 noarch
kernel 2.4.18 5 i686
cracklib 2.7 15 i386
libtool-libs 1.4.2 7 i386
perl-Text-Wrapper 1.000 10 i386
php-imap 4.1.2 7 i386
eject 2.0.12 4 i386
dump 0.4b25 1.72.1es i386
freeswan-module 1.98b_2.4.18_5 1es2 i586
mod_auth_external 2.1.2 6 i386
samba 2.2.5 4 i386
mutt 1.2.5.1 1 i386
readline 4.2a 4 i386
traceroute 1.4a12 2 i386
slang 1.4.5 2 i386
mysql-server 3.23.49 3 i386
openssl 0.9.6b 28 i386
e-smith-rpm 0.1.5 01 noarch
php-mysql 4.1.2 7 i386
buffer 1.19 5 i386
perl-Error 0.14 01 i386
gpm 1.19.3 21 i386
xinetd 2.3.4 0.8 i386
perl-Time-HiRes 1.20 14 i386
e-smith-formmagick 0.3.2 01 noarch
popt 1.6.4 7x.18 i386
vim-common 6.1 2 i386
ed 0.2 25 i386
e2fsprogs 1.27 3 i386
groff 1.17.2 12 i386
vixie-cron 3.0.1 64 i386
kernel-pcmcia-cs 3.1.27 18 i386
iptables 1.2.5 3 i386
dhcpcd 1.3.22pl1 7 i386
e-smith-proftpd 1.7.2 01 noarch
mailcap 2.1.9 2 noarch
flexbackup 0.9.8 06es noarch
initscripts 6.67 1es5 i386
tmpwatch 2.8.3 1 i386
db3 3.3.11 6 i386
e-smith-mysql 1.7.3 01 noarch
gawk 3.1.0 4 i386
pidentd 2.8.5 3+masq i386
perl-URI 1.17 16 i386
mingetty 1.00 1 i386
bzip2 1.0.2 2 i386
isdn4k-utils 3.1 53 i386
e-smith-devtools 1.9.0 01 noarch
tcpdump 3.6.2 12 i386
tnef 1.1.1 1 i386
e-smith-blades 1.5.11 01 noarch
libcap 1.10 8 i386
freeswan-module 1.98b_2.4.18_5 1es2 i686
rpm-build 4.0.4 7x.18 i386
shadow-utils 20000902 7 i386
perl-HTML-Tagset 3.03 14 i386
krb5-libs 1.2.4 2 i386
squid 2.4.STABLE6 6.7.3 i386
psmisc 20.2 3.73 i386
LPRng 3.8.9 4 i386
ntp 4.1.1 1 i386
horde 2.0 5es noarch
libxml2 2.4.19 4 i386
perl-Crypt-SSLeay 0.35 15 i386
newt 0.50.18 04es i386
perl-libwww-perl 5.63 9 i386
basesystem 7.0 2 noarch
pine 4.44 7 i386
ncurses4 5.0 5 i386
glib2 2.0.1 2 i386
perl-Quota 1.4 2 i386
perl-NDBM_File 1.75 34.99.6 i386
unzip 5.50 2 i386
telnet 0.17.6x 18 i386
perl-CGI-FormMagick 0.87 03es i386
perl-Authen-PAM 0.12 1 i386
anacron 2.3 17 i386
kudzu 0.99.52 1 i386
ucd-snmp 4.2.5 7.73.0 i386
openssh-server 3.1p1 6 i386
php 4.1.2 7 i386
e-smith-lilo 1.9.5 01 noarch
e-smith-packetfilter 1.9.14 01 noarch
e-smith-php 1.7.1 01 noarch
php-ldap 4.1.2 7 i386
at 3.1.8 23 i386
cvs 1.11.1p1 7es1 i386
e-smith-lib-compspec 0.1.2 01 noarch
sysklogd 1.4.1 8 i386
ucspi-tcp 0.88 03 i386
sash 3.4 11 i386
perl-DB_File 1.75 34.99.6 i386
e-smith-keys 1.2.0 02 noarch
libstdc++ 2.96 112 i386
glibc 2.2.5 39 i686
bdflush 1.5 17 i386
diald-top 2.1pl4 2es i386
perl-Convert-ASN1 0.07 10 i386
wireless-tools 23 2 i386
rpm 4.0.4 7x.18 i386
python2 2.2 16 i386
e-smith-viewlogfiles 1.1.2 01 noarch
tcsh 6.10 6 i386
e-smith-flexbackup 1.5.2 01 noarch
procps 2.0.7 12 i386
rpm-perl 4.0.4 7x.18 i386
e-smith-base 4.11.25 01 noarch
e-smith-pptpd 1.5.2 01 noarch
crontabs 1.10 1 noarch
pam 0.75 32 i386
vim-enhanced 6.1 2 i386
perl-DBI 1.21 1 i386
mktemp 1.5 14 i386
fastforward 0.51 03 i386
mysql-devel 3.23.49 3 i386
perl-Filter-Handle 0.03 10 i386
glibc-common 2.2.5 39 i386
rmt 0.4b27 3 i386
gnupg 1.0.6 5 i386
libpcap 0.6.2 12 i386
qmail 1.03 06 i386
dot-forward 0.71 02 i386
termcap 11.0.1 10 noarch
samba-common 2.2.5 4 i386
e-smith-wu-imap 1.5.0 01 noarch
tcp_wrappers 7.6 19 i386
perl-gettext 1.01 10 i386
sh-utils 2.0.11 14 i386
mod_perl 1.26 5 i386
perl-DBD-MySQL 1.2219 6 i386
freetype 2.0.9 2 i386
mod_ssl 2.8.7 6 i386
freeswan 1.98b_2.4.18_5 0 i386
authconfig 4.2.8 4 i386
openssh 3.1p1 6 i386
rp-pppoe 3.3 7 i386
MAKEDEV 3.3 4 i386
perl-CGI-Persistent 0.22 3 i386
man 1.5j 6 i386
libjpeg 6b 19 i386
sudo 1.6.5p2 2 i386
ispell 3.1.20 27 i386
pptp-conntrack-nat 1.0.0 1es i386
e-smith-proxy 4.9.5 01 noarch
mailx 8.1.1 22 i386
perl-Test-Harness-Straps 0.10 1 noarch
e-smith-boot-image 1.7.0 01 noarch
diffutils 2.7.2 5 i386
diald 0.99.4 2 i386
kernel-smp 2.4.18 5 i586
perl-Digest-SHA1 2.01 1 i386
words 2 18 noarch
pwdb 0.61.2 2 i386
e-smith-ldap 4.7.6 01 noarch
less 358 24 i386
sshell 2.1 04 i386
e-smith-support 1.3.12 01 noarch
e-smith-lib 1.11.10 01 noarch
syslinux 1.52 2 i386
autopassword 2.0 3 i386
openldap-clients 2.0.23 4 i386
net-tools 1.60 4 i386
perl-CGI 2.752 34.99.6 i386
bash 2.05a 13 i386
e-smith-named 1.9.3 01 noarch
mkbootdisk 1.4.3 1es i386
mkinitrd 3.3.10 1 i386
ncurses 5.2 26 i386
compat-libstdc++ 6.2 2.9.0.16 i386
openldap 2.0.23 4 i386
imap 2001a 1.72.0mdir5 i386
dvdrecord 0.1.2 1 i386
tai64nunix 0.70 03 i386
pciutils 2.1.9 2 i386
e-smith-LPRng 1.7.1 01 noarch
curl 7.9.5 2 i386
pspell 0.12.2 8 i386
sed 3.02 11 i386
mailfront 0.76 1 i386
kernel 2.4.18 5 i386
telnet-server 0.17.6x 18 i386
db2 2.4.14 10 i386
hwdata 0.14 1es noarch
cpio 2.4.2 26 i386
setserial 2.17 5 i386
mount 2.11n 12.7.3 i386
ash 0.3.7 2 i386
mtools 3.9.8 2 i386
kbdconfig 1.9.15 2 i386
daemontools 0.70 05 i386
bzip2-libs 1.0.2 2 i386
perl-Test-Inline 0.14 1 i386
kernel-smp 2.4.18 5 i686
supervise-scripts 3.3 1es1 noarch
console-tools 19990829 40 i386
patch 2.5.4 12 i386
usermode 1.53 2 i386
e-smith-backup 1.9.0 01 noarch
chkconfig 1.3.5 3 i386
cyrus-sasl-md5 1.5.24 25 i386
ftp 0.17 13 i386
e-smith-ntp 1.9.3 01 noarch
gdbm 1.8.0 14 i386
losetup 2.11n 12.7.3 i386
dev 3.3 4 i386
e-smith-release 5.6alpha6 01 noarch
zlib 1.1.3 25.7 i386
gd 1.8.4 4 i386
openldap-servers 2.0.23 4 i386
cyrus-sasl 1.5.24 25 i386
checkpassword 0.90 02 i386
perl-Clone 0.13 1 i386
e-smith-telnet 1.3.1 01 noarch
rootfiles 7.2 1 noarch
lilo 21.4.4 14 i386
expat 1.95.2 2 i386
SMEServer 5.6 01 noarch
whois 1.0.10 1 i386
cracklib-dicts 2.7 15 i386
mc 4.5.55 5 i386
apmd 3.0.2 10 i386
perl-Object-Persistence 0.92 2 i386
e-smith-email 4.11.7 01 noarch
modutils 2.4.14 3 i386
mouseconfig 4.25 1 i386
python 1.5.2 38 i386
tcl 8.3.3 69 i386
perl-WWW-Automate 0.20 1 i386
e-smith-horde 1.5.2 01 noarch
indexhtml 7.3 3 noarch
perl-MailTools 1.40 1 i386
apache 1.3.23 14es1 i386
netatalk 1.5.3.1 4 i386
lockdev 1.0.0 16 i386
slocate 2.6 1 i386
bind 9.2.1 0.7x i386
e-smith-quota 1.5.2 01 noarch
textutils 2.0.11 7 i386
samba-client 2.2.5 4 i386
freeswan-module 1.98b_2.4.18_5 1es2 i386
perl-MIME-Base64 2.12 14 i386
openssh-clients 3.1p1 6 i386
hdparm 4.6 1 i386
mt-st 0.7 3 i386
perl-suidperl 5.6.1 34.99.6 i386
perl-Class-ParamParser 1.0401 1 i386
e-smith-imp 1.7.2 01 noarch
SysVinit 2.84 2 i386
mysqlclient9 3.23.22 6 i386
setup 2.5.7 01es noarch
bind-utils 9.2.1 0.7x i386
sharutils 4.2.1 9 i386
vim-minimal 6.1 2 i386
db1 1.85 8 i386
hotplug 2002_04_01 3 i386
perl-Crypt-Cracklib 0.01 1 i386
e-smith-apache-proxy 0.1.0 01 noarch
e-smith-reinstall-floppy 1.9.0 01 noarch
stat 2.5 5 i386
ppp-mppe-modules 2.4.2 4es i386
libtermcap 2.0.8 28 i386
pptpd 1.1.2 03 i386
quota 3.03 1es1 i386
logrotate 3.6.4 1 i386
mm 1.1.3 8 i386
perl-HTML-Parser 3.26 2 i386
perl-Text-Template 1.43 1es1 i386
e-smith-manager 1.7.2 01 noarch
perl-Digest-MD5 2.20 1 i386
e-smith-qmailanalog 1.7.0 01 noarch
e-smith-turba 0.21.3 01 noarch
minicom 2.00.0 3 i386
e-smith-daemontools 1.3.2 01 noarch
proftpd 1.2.0rc3 2es i386
info 4.1 1 i386
iproute 2.4.7 1 i386
wget 1.8.1 4 i386
stunnel 3.22 1 i386
libsmbpw 1.1 3 i386
e-smith-locale-fr_CA 1.3.7 01 noarch
iputils 20020124 3 i386
ppp 2.4.0 16 i386
perl-Test-Simple 0.42 1 i386
e-smith-hosts 1.9.0 01 noarch
e-smith-rp-pppoe 1.7.6 01 noarch
fetchmail 5.9.0 11 i386
rcs 5.7 15 i386
fileutils 4.1 10 i386
kernel 2.4.18 5 i586
perl-FreezeThaw 0.41 10 i386
raidtools 1.00.2 1.3 i386
util-linux 2.11n 12.7.3 i386
e-smith-qmail 1.5.1 01 noarch
glibc 2.2.5 39 i386
e-smith-dynamicdns-tzo 1.3.1 01 noarch
lynx 2.8.4 18 i386
libpng 1.0.14 0.70.1 i386
glib 1.2.10 5 i386
passwd 0.67 1 i386
turba 1.0 6es noarch
bc 1.06 8 i386
e-smith-samba 1.7.2 01 noarch
e-smith-ipmasq 1.7.4 01 noarch
qmailanalog 0.70 03 i386
gzip 1.3.3 1 i386
procmail 3.22 5 i386
e-smith-netatalk 1.9.3 01 noarch
e-smith 4.2.0 06 noarch
findutils 4.1.7 4 i386
mysql 3.23.49 3 i386
perl-XML-Parser 2.30 15 i386
file 3.37 5 i386
e-smith-dynamicdns-yi 1.3.0 01 noarch
perl-I18N-LangTags 0.13 10 i386
which 2.13 3 i386
e-smith-mailfront 0.3.5 01 noarch
kernel-utils 2.4 7.4 i386
utempter 0.5.2 6 i386
imp 3.0 4es noarch
dhcp 2.0pl5 8 i386
lsof 4.51 2 i386
usbutils 0.9 5 i386
pcre 3.9 2 i386
strace 4.4 4 i386
cdrecord 1.10 11 i386
filesystem 2.1.6 2 noarch
time 1.7 16 i386
shapecfg 2.2.12 8 i386
maildrop 1.3.0 1.7.0 i386
e-smith-test 0.3.0 01 noarch
binutils 2.11.93.0.2 11 i386
rsync 2.5.4 2 i386
gmp 4.0.1 3 i386
grep 2.5.1 1 i386
tar 1.13.25 4 i386
